searchNodes=[{"doc":"Supports the CLDR Units definitions which provide for the localization of many unit types. The primary public API defines: Cldr.Unit.to_string/3 which, given a unit or unit list will output a localized string Cldr.Unit.known_units/0 identifies the available units for localization Cldr.Unit.{add, sub, mult, div}/2 to support basic unit mathematics between units of compatible type (like length or volume) Cldr.Unit.compare/2 to compare one unit to another unit as long as they are convertible. Cldr.Unit.convert/2 to convert one unit to another unit as long as they are convertible. Cldr.Unit.localize/3 will convert a unit into the units preferred for a given locale and usage Cldr.Unit.preferred_units/3 which, for a given unit and locale, will return a list of preferred units that can be applied to Cldr.Unit.decompose/2 Cldr.Unit.decompose/2 to take a unit and return a list of units decomposed by a list of smaller units.","ref":"Cldr.Unit.html","title":"Cldr.Unit","type":"module"},{"doc":"See Cldr.Unit.Math.add!/2 .","ref":"Cldr.Unit.html#add!/2","title":"Cldr.Unit.add!/2","type":"function"},{"doc":"See Cldr.Unit.Math.add/2 .","ref":"Cldr.Unit.html#add/2","title":"Cldr.Unit.add/2","type":"function"},{"doc":"Returns the base unit for a given unit. Argument unit is either a t:Cldr.Unit , an atom or a t:String Returns {:ok, base_unit} or {:error, {exception, reason}} Example iex&gt; Cldr.Unit . base_unit :square_kilometer { :ok , :square_meter } iex&gt; Cldr.Unit . base_unit :square_table { :error , { Cldr.UnknownUnitError , &quot;Unknown unit was detected at \\&quot; table \\&quot; &quot; } }","ref":"Cldr.Unit.html#base_unit/1","title":"Cldr.Unit.base_unit/1","type":"function"},{"doc":"Returns a mapping of base units to their respective unit categories. Base units are a common unit for a given unit category which are used in two scenarios: When converting between units. If two units have the same base unit they can be converted to each other. See Cldr.Unit.Conversion . When identifying the preferred units for a given locale or territory, the base unit is used to aid identification of preferences for given use cases. See Cldr.Unit.Preference . Example =&gt; Cldr.Unit . base_unit_category_map %{ &quot;kilogram_square_meter_per_cubic_second_ampere&quot; =&gt; :voltage , &quot;kilogram_meter_per_meter_square_second&quot; =&gt; :torque , &quot;square_meter&quot; =&gt; :area , &quot;kilogram&quot; =&gt; :mass , &quot;kilogram_square_meter_per_square_second&quot; =&gt; :energy , &quot;revolution&quot; =&gt; :angle , &quot;candela_per_square_meter&quot; =&gt; :luminance , ... }","ref":"Cldr.Unit.html#base_unit_category_map/0","title":"Cldr.Unit.base_unit_category_map/0","type":"function"},{"doc":"Returns a mapping from unit categories to the base unit.","ref":"Cldr.Unit.html#base_units/0","title":"Cldr.Unit.base_units/0","type":"function"},{"doc":"See Cldr.Unit.Math.compare/2 .","ref":"Cldr.Unit.html#compare/2","title":"Cldr.Unit.compare/2","type":"function"},{"doc":"Returns a boolean indicating if two units are of the same unit category. Arguments unit_1 and unit_2 are any units returned by Cldr.Unit.new/2 or a valid unit name. Returns true or false Examples iex&gt; Cldr.Unit . compatible? :foot , :meter true iex&gt; Cldr.Unit . compatible? Cldr.Unit . new! ( :foot , 23 ) , :meter true iex&gt; Cldr.Unit . compatible? :foot , :liter false iex&gt; Cldr.Unit . compatible? &quot;light_year_per_second&quot; , &quot;meter_per_gallon&quot; false","ref":"Cldr.Unit.html#compatible?/2","title":"Cldr.Unit.compatible?/2","type":"function"},{"doc":"See Cldr.Unit.Conversion.convert!/2 .","ref":"Cldr.Unit.html#convert!/2","title":"Cldr.Unit.convert!/2","type":"function"},{"doc":"See Cldr.Unit.Conversion.convert/2 .","ref":"Cldr.Unit.html#convert/2","title":"Cldr.Unit.convert/2","type":"function"},{"doc":"Decomposes a unit into subunits. Any list compatible units can be provided however a list of units of decreasing scale is recommended. For example [:foot, :inch] or [:kilometer, :meter, :centimeter, :millimeter] Arguments unit is any unit returned by Cldr.Unit.new/2 unit_list is a list of valid units (one or more from the list returned by Cldr.Unit.known_units/0 . All units must be from the same unit category. format_options is a Keyword list of options that is added to the last unit in unit_list . The format_options will be applied when calling Cldr.Unit.to_string/3 on the unit . The default is [] . Returns a list of units after decomposition or an error tuple Examples iex&gt; u = Cldr.Unit . new! ( 10.3 , :foot ) iex&gt; Cldr.Unit . decompose u , [ :foot , :inch ] [ Cldr.Unit . new! ( :foot , 10 ) , Cldr.Unit . new! ( :inch , Ratio . new ( 18 , 5 ) ) ] iex&gt; u = Cldr.Unit . new! ( :centimeter , 1111 ) iex&gt; Cldr.Unit . decompose u , [ :kilometer , :meter , :centimeter , :millimeter ] [ Cldr.Unit . new! ( :meter , 11 ) , Cldr.Unit . new! ( :centimeter , 11 ) ]","ref":"Cldr.Unit.html#decompose/3","title":"Cldr.Unit.decompose/3","type":"function"},{"doc":"Returns the default formatting style. Example iex&gt; Cldr.Unit . default_style :long","ref":"Cldr.Unit.html#default_style/0","title":"Cldr.Unit.default_style/0","type":"function"},{"doc":"Returns the localized display name for a unit. The returned text is generally suitable for including in UI elements such as selection boxes. Arguments unit is any t:Cldr.Unit or any unit name returned by Cldr.Unit.known_units/0 . options is a keyword list of options. Options :locale is any valid locale name returned by Cldr.known_locale_names/0 or a Cldr.LanguageTag struct. The default is Cldr.get_locale/0 . backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . :style is one of those returned by Cldr.Unit.available_styles . The current styles are :long , :short and :narrow . The default is style: :long . Examples iex&gt; Cldr.Unit . display_name :liter &quot;liters&quot; iex&gt; Cldr.Unit . display_name :liter , locale : &quot;fr&quot; &quot;litres&quot; iex&gt; Cldr.Unit . display_name :liter , locale : &quot;fr&quot; , style : :short &quot;l&quot;","ref":"Cldr.Unit.html#display_name/2","title":"Cldr.Unit.display_name/2","type":"function"},{"doc":"See Cldr.Unit.Math.div!/2 .","ref":"Cldr.Unit.html#div!/2","title":"Cldr.Unit.div!/2","type":"function"},{"doc":"See Cldr.Unit.Math.div/2 .","ref":"Cldr.Unit.html#div/2","title":"Cldr.Unit.div/2","type":"function"},{"doc":"Returns a new Unit.t struct from a map. A map representation of a unit may be generated from json or other external format data. The map provided must have the keys unit and value in either String.t or atom (both keys must be of the same type). value must be either an integer, a float or a map representation of a rational number. A rational number map has the keys numerator and denominator in either String.t or atom format (both keys must be of the same type). Arguments map is a map with the keys unit and value Returns {:ok, unit} or {:error, {exception, reason}} Examples Cldr.Unit . from_map %{ value : 1 , unit : &quot;kilogram&quot; } =&gt; { :ok , # Cldr.Unit &lt; :kilogram , 1 &gt; } Cldr.Unit . from_map %{ value : %{ numerator : 3 , denominator : 4 } , unit : &quot;kilogram&quot; } =&gt; { :ok , # Cldr.Unit &lt; :kilogram , 3 &lt;|&gt; 4 &gt; } Cldr.Unit . from_map %{ &quot;value&quot; =&gt; 1 , &quot;unit&quot; =&gt; &quot;kilogram&quot; } =&gt; { :ok , # Cldr.Unit &lt; :kilogram , 1 &gt; }","ref":"Cldr.Unit.html#from_map/1","title":"Cldr.Unit.from_map/1","type":"function"},{"doc":"Return the grammatical gender for a unit. Arguments Options Returns Examples","ref":"Cldr.Unit.html#grammatical_gender/2","title":"Cldr.Unit.grammatical_gender/2","type":"function"},{"doc":"","ref":"Cldr.Unit.html#grammatical_gender_error/2","title":"Cldr.Unit.grammatical_gender_error/2","type":"function"},{"doc":"Inverts a unit Only &quot;per&quot; units can be inverted.","ref":"Cldr.Unit.html#invert/1","title":"Cldr.Unit.invert/1","type":"function"},{"doc":"Returns a list of the known grammatical cases. A grammatical case can be provided as an option to Cldr.Unit.to_string/2 in order to localise a unit appropriate to the context in which it is used. Example iex&gt; Cldr.Unit . known_grammatical_cases ( ) [ :abessive , :ablative , :accusative , :adessive , :allative , :causal , :comitative , :dative , :delative , :elative , :ergative , :genitive , :illative , :inessive , :instrumental , :locative , :localtivecopulative , :nominative , :oblique , :partitive , :prepositional , :sociative , :sublative , :superessive , :terminative , :translative , :vocative ]","ref":"Cldr.Unit.html#known_grammatical_cases/0","title":"Cldr.Unit.known_grammatical_cases/0","type":"function"},{"doc":"Returns a list of the known grammatical genders. A gender can be provided as an option to Cldr.Unit.to_string/2 in order to localise a unit appropriate to the context in which it is used. Example iex&gt; Cldr.Unit . known_grammatical_genders [ :animate , :inanimate , :personal , :common , :feminine , :masculine , :neuter ]","ref":"Cldr.Unit.html#known_grammatical_genders/0","title":"Cldr.Unit.known_grammatical_genders/0","type":"function"},{"doc":"Return a list of known measurement system names. Example iex&gt; Cldr.Unit . known_measurement_system_names ( ) [ :metric , :si , :uksystem , :ussystem ]","ref":"Cldr.Unit.html#known_measurement_system_names/0","title":"Cldr.Unit.known_measurement_system_names/0","type":"function"},{"doc":"Return a list of known measurement systems. Example iex&gt; Cldr.Unit . known_measurement_systems ( ) %{ metric : %{ alias : nil , description : &quot;Metric System&quot; } , uksystem : %{ alias : :imperial , description : &quot;UK System of measurement: feet, pints, etc.; pints are 20oz&quot; } , ussystem : %{ alias : nil , description : &quot;US System of measurement: feet, pints, etc.; pints are 16oz&quot; } , si : %{ alias : nil , description : &quot;SI System&quot; } }","ref":"Cldr.Unit.html#known_measurement_systems/0","title":"Cldr.Unit.known_measurement_systems/0","type":"function"},{"doc":"Returns the known styles for a unit. Example iex&gt; Cldr.Unit . known_styles [ :long , :short , :narrow ]","ref":"Cldr.Unit.html#known_styles/0","title":"Cldr.Unit.known_styles/0","type":"function"},{"doc":"Returns a list of the known unit categories. Example iex&gt; Cldr.Unit . known_unit_categories [ :acceleration , :angle , :area , :concentr , :consumption , :digital , :duration , :electric , :energy , :force , :frequency , :graphics , :length , :light , :mass , :power , :pressure , :speed , :temperature , :torque , :volume ]","ref":"Cldr.Unit.html#known_unit_categories/0","title":"Cldr.Unit.known_unit_categories/0","type":"function"},{"doc":"Returns the known units that are directly translatable. These units have localised content in CLDR and are used as a key to retrieving that content. Example =&gt; Cldr.Unit . known_units [ :acre , :acre_foot , :ampere , :arc_minute , :arc_second , :astronomical_unit , :bit , :bushel , :byte , :calorie , :carat , :celsius , :centiliter , :centimeter , :century , :cubic_centimeter , :cubic_foot , :cubic_inch , :cubic_kilometer , :cubic_meter , :cubic_mile , :cubic_yard , :cup , :cup_metric , :day , :deciliter , :decimeter , :degree , :fahrenheit , :fathom , :fluid_ounce , :foodcalorie , :foot , :furlong , :g_force , :gallon , :gallon_imperial , :generic , :gigabit , :gigabyte , :gigahertz , :gigawatt , :gram , :hectare , :hectoliter , :hectopascal , :hertz , :horsepower , :hour , :inch , ... ]","ref":"Cldr.Unit.html#known_units/0","title":"Cldr.Unit.known_units/0","type":"function"},{"doc":"Returns the units that are defined for a given category (such as :volume, :length) See also Cldr.Unit.known_unit_categories/0 . Example =&gt; Cldr.Unit . known_units_by_category %{ acceleration : [ :g_force , :meter_per_square_second ] , angle : [ :arc_minute , :arc_second , :degree , :radian , :revolution ] , area : [ :acre , :dunam , :hectare , :square_centimeter , :square_foot , :square_inch , :square_kilometer , :square_meter , :square_mile , :square_yard ] , concentr : [ :karat , :milligram_per_deciliter , :millimole_per_liter , :mole , :percent , :permille , :permillion , :permyriad ] , ... }","ref":"Cldr.Unit.html#known_units_by_category/0","title":"Cldr.Unit.known_units_by_category/0","type":"function"},{"doc":"Returns the list of units defined for a given category. Arguments category is any unit category returned by Cldr.Unit.known_unit_categories/0 . See also Cldr.Unit.known_units_by_category/0 . Example =&gt; Cldr.Unit . known_units_for_category :volume { :ok , [ :cubic_centimeter , :centiliter , :hectoliter , :cubic_kilometer , :acre_foot , ... ] }","ref":"Cldr.Unit.html#known_units_for_category/1","title":"Cldr.Unit.known_units_for_category/1","type":"function"},{"doc":"Localizes a unit according to the current processes locale and backend. The current process's locale is set with Cldr.put_locale/1 . See Cldr.Unit.localize/3 for further details.","ref":"Cldr.Unit.html#localize/1","title":"Cldr.Unit.localize/1","type":"function"},{"doc":"Localizes a unit according to a territory A territory can be derived from a t:Cldr.Locale.locale_name or t:Cldr.LangaugeTag . Use this function if you have a unit which should be presented in a user interface using units relevant to the audience. For example, a unit #Cldr.Unit100, :meter&gt; might be better presented to a US audience as #Cldr.Unit&lt;328, :foot&gt; . Arguments unit is any unit returned by Cldr.Unit.new/2 backend is any module that includes use Cldr and therefore is a Cldr backend module. options is a keyword list of options Options :locale is any valid locale name returned by Cldr.known_locale_names/0 or a Cldr.LanguageTag struct. The default is backend.get_locale/0 . :territory is any valid territory code returned by Cldr.known_territories/0 . The default is the territory defined as part of the :locale . The option :territory has a precedence over the territory in a locale. :usage is the way in which the unit is intended to be used. The available usage varyies according to the unit category. See Cldr.Unit.preferred_units/3 . Examples iex&gt; unit = Cldr.Unit . new! ( 1.83 , :meter ) iex&gt; Cldr.Unit . localize ( unit , usage : :person_height , territory : :US ) [ Cldr.Unit . new! ( :foot , 6 , usage : :person_height ) , Cldr.Unit . new! ( :inch , Ratio . new ( 6485183463413016 , 137269716642252725 ) , usage : :person_height ) ]","ref":"Cldr.Unit.html#localize/3","title":"Cldr.Unit.localize/3","type":"function"},{"doc":"Returns the default measurement system for a territory and a given system key. Arguments territory is any valid territory returned by Cldr.validate_territory/1 key is any measurement system key. The known keys are :default , :temperature and :paper_size . The default key is :default . Examples iex&gt; Cldr.Unit . measurement_system_for_territory :US :ussystem iex&gt; Cldr.Unit . measurement_system_for_territory :GB :uksystem iex&gt; Cldr.Unit . measurement_system_for_territory :AU :metric iex&gt; Cldr.Unit . measurement_system_for_territory :US , :temperature :ussystem iex&gt; Cldr.Unit . measurement_system_for_territory :GB , :temperature :uksystem iex&gt; Cldr.Unit . measurement_system_for_territory :GB , :volume { :error , { Cldr.Unit.InvalidSystemKeyError , &quot;The key :volume is not known. Valid keys are :default, :paper_size and :temperature&quot; } }","ref":"Cldr.Unit.html#measurement_system_for_territory/2","title":"Cldr.Unit.measurement_system_for_territory/2","type":"function"},{"doc":"Determines the preferred measurement system from a locale. See also Cldr.Unit.known_measurement_systems/0 . Arguments locale is any valid locale name returned by Cldr.known_locale_names/0 or a t:Cldr.LanguageTag struct. The default is Cldr.get_locale/0 . key is any measurement system key. The known keys are :default , :temperature and :paper_size . The default key is :default . Examples iex&gt; Cldr.Unit . measurement_system_from_locale &quot;en&quot; :ussystem iex&gt; Cldr.Unit . measurement_system_from_locale &quot;en-GB&quot; :uksystem iex&gt; Cldr.Unit . measurement_system_from_locale &quot;en-AU&quot; :metric iex&gt; Cldr.Unit . measurement_system_from_locale &quot;en-AU-u-ms-ussystem&quot; :ussystem iex&gt; Cldr.Unit . measurement_system_from_locale &quot;en-GB&quot; , :temperature :uksystem iex&gt; Cldr.Unit . measurement_system_from_locale &quot;en-AU&quot; , :paper_size :a4 iex&gt; Cldr.Unit . measurement_system_from_locale &quot;en-GB&quot; , :invalid { :error , { Cldr.Unit.InvalidSystemKeyError , &quot;The key :invalid is not known. Valid keys are :default, :paper_size and :temperature&quot; } }","ref":"Cldr.Unit.html#measurement_system_from_locale/2","title":"Cldr.Unit.measurement_system_from_locale/2","type":"function"},{"doc":"","ref":"Cldr.Unit.html#measurement_system_from_locale/3","title":"Cldr.Unit.measurement_system_from_locale/3","type":"function"},{"doc":"Returns the list of units defined in a given measurement system. Arguments system is any measurement system returned by Cldr.Unit.known_measurement_systems/0 Returns A list of translatable units as atoms or {:error, {exception, message}} Example =&gt; Cldr.Unit . measurement_system_units :uksystem [ :ton , :inch , :yard , ... ]","ref":"Cldr.Unit.html#measurement_system_units/1","title":"Cldr.Unit.measurement_system_units/1","type":"function"},{"doc":"Returns a boolean indicating if a given unit belongs to one or more measurement systems. When a list or more than one measurement system is provided, the test is one of inclusion. That is, if the unit belongs to any of the provided measurement systems the return is true . Arguments system is any measurement system or list of measurement systems returned by Cldr.Unit.known_measurement_systems/0 Returns true or false or {:error, {exception, message}} Examples iex&gt; Cldr.Unit . measurement_system? :foot , :uksystem true iex&gt; Cldr.Unit . measurement_system? :foot , [ :uksystem , :ussystem ] true iex&gt; Cldr.Unit . measurement_system? :foot , [ :metric ] false iex&gt; Cldr.Unit . measurement_system? :invalid , [ :metric ] { :error , { Cldr.UnknownUnitError , &quot;The unit :invalid is not known.&quot; } }","ref":"Cldr.Unit.html#measurement_system?/2","title":"Cldr.Unit.measurement_system?/2","type":"function"},{"doc":"See Cldr.Unit.measurement_systems_by_territory/0 .","ref":"Cldr.Unit.html#measurement_systems/0","title":"Cldr.Unit.measurement_systems/0","type":"function"},{"doc":"Returns a map of measurement systems by territory. Example =&gt; Cldr.Unit . measurement_systems_by_territory %{ KE : %{ default : :metric , paper_size : :a4 , temperature : :metric } , GU : %{ default : :metric , paper_size : :a4 , temperature : :metric } , ... }","ref":"Cldr.Unit.html#measurement_systems_by_territory/0","title":"Cldr.Unit.measurement_systems_by_territory/0","type":"function"},{"doc":"Returns the measurement systems for a given unit. Arguments unit is any t:Cldr.Unit or any unit returned by Cldr.Unit.known_units/0 or a string unit name. Returns A list of measurement systems to which the unit belongs. {:error, {exception, message}} Examples iex&gt; Cldr.Unit . measurement_systems_for_unit :foot [ :ussystem , :uksystem ] iex&gt; Cldr.Unit . measurement_systems_for_unit :meter [ :metric , :si ] iex&gt; Cldr.Unit . measurement_systems_for_unit :invalid { :error , { Cldr.UnknownUnitError , &quot;The unit :invalid is not known.&quot; } }","ref":"Cldr.Unit.html#measurement_systems_for_unit/1","title":"Cldr.Unit.measurement_systems_for_unit/1","type":"function"},{"doc":"See Cldr.Unit.Math.mult!/2 .","ref":"Cldr.Unit.html#mult!/2","title":"Cldr.Unit.mult!/2","type":"function"},{"doc":"See Cldr.Unit.Math.mult/2 .","ref":"Cldr.Unit.html#mult/2","title":"Cldr.Unit.mult/2","type":"function"},{"doc":"Returns a new Unit.t struct or raises on error. Arguments value is any float, integer or Decimal unit is any unit returned by Cldr.Unit.known_units/0 Returns unit or raises an exception Examples iex&gt; Cldr.Unit . new! 23 , :gallon # Cldr.Unit &lt; :gallon , 23 &gt; Cldr.Unit . new! 14 , :gadzoots ** (Cldr.UnknownUnitError) The unit :gadzoots is not known. (ex_cldr_units) lib/cldr/unit.ex:57: Cldr.Unit.new!/2","ref":"Cldr.Unit.html#new!/3","title":"Cldr.Unit.new!/3","type":"function"},{"doc":"Returns a new Unit.t struct. Arguments value is any float, integer, Ratio or Decimal unit is any unit name returned by Cldr.Unit.known_units/0 options is Keyword list of options. The default is [] Options :usage is the intended use of the unit. This is used during localization to convert the unit to that appropriate for the unit category, usage, target territory and unit value. The usage must be defined for the unit's category. See Cldr.Unit.unit_category_usage/0 for the known usage types for each category. Returns unit or {:error, {exception, message}} Examples iex&gt; Cldr.Unit . new ( 23 , :gallon ) { :ok , Cldr.Unit . new! ( :gallon , 23 ) } iex&gt; Cldr.Unit . new ( :gallon , 23 ) { :ok , Cldr.Unit . new! ( :gallon , 23 ) } iex&gt; Cldr.Unit . new ( 14 , :gadzoots ) { :error , { Cldr.UnknownUnitError , &quot;Unknown unit was detected at \\&quot; gadzoots \\&quot; &quot; } } Cldr.Unit . new ( :gallon , 23 , usage : :fluid ) #=&gt; {:ok, #Cldr.Unit&lt;:gallon, 23, usage: :fluid, format_options: []&gt;}","ref":"Cldr.Unit.html#new/3","title":"Cldr.Unit.new/3","type":"function"},{"doc":"Parse a string to create a new unit or raises an exception. This function attempts to parse a string into a number and unit type . If successful it attempts to create a new unit using Cldr.Unit.new/3 . The parsed unit type is un-aliased against all the known unit names for a give locale (or the current locale if no locale is specified). The known aliases for unit types can be returned with MyApp.Cldr.Unit.unit_strings_for/1 where MyApp.Cldr is the name of a backend module. Arguments unit string is any string to be parsed and if possible used to create a new t:Cldr.Unit options is a keyword list of options Options :locale is any valid locale name returned by Cldr.known_locale_names/0 or a t:Cldr.LanguageTag struct. The default is Cldr.get_locale/0 :backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . :only is a unit category or unit, or a list of unit categories and units. The parsed unit must match one of the categories or units in order to be valid. This is helpful when disambiguating parsed units. For example, parsing &quot;2w&quot; could be either &quot;2 watts&quot; or &quot;2 weeks&quot;. Specifying only: :duration would return &quot;2 weeks&quot;. Specifying only: :power would return &quot;2 watts&quot; :except is the oppostte of :only . The parsed unit must not match the specified unit or category, or unit categories and units. Notes When both :only and :except options are passed, both conditions must be true in order to return a parsed result. Only units returned by Cldr.Unit.known_units/0 can be used in the :only and :except filters. Returns unit or raises an exception Examples iex&gt; Cldr.Unit . parse! &quot;1kg&quot; Cldr.Unit . new! ( 1 , :kilogram ) iex&gt; Cldr.Unit . parse! &quot;1 tages&quot; , locale : &quot;de&quot; Cldr.Unit . new! ( 1 , :day ) iex&gt; Cldr.Unit . parse! ( &quot;42 candela per lux&quot; ) Cldr.Unit . new! ( 42 , &quot;candela per lux&quot; ) iex&gt; Cldr.Unit . parse! ( &quot;42 millispangels&quot; ) ** (Cldr.UnknownUnitError) Unknown unit was detected at &quot;spangels&quot;","ref":"Cldr.Unit.html#parse!/2","title":"Cldr.Unit.parse!/2","type":"function"},{"doc":"Parse a string to create a new unit. This function attempts to parse a string into a number and unit type . If successful it attempts to create a new unit using Cldr.Unit.new/3 . The parsed unit type is aliased against all the known unit names for a give locale (or the current locale if no locale is specified). The known aliases for unit types can be returned with MyApp.Cldr.Unit.unit_strings_for/1 where MyApp.Cldr is the name of a backend module. Arguments unit string is any string to be parsed and if possible used to create a new t:Cldr.Unit options is a keyword list of options Options :locale is any valid locale name returned by Cldr.known_locale_names/0 or a t:Cldr.LanguageTag struct. The default is Cldr.get_locale/0 :backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . :only is a unit category or unit, or a list of unit categories and units. The parsed unit must match one of the categories or units in order to be valid. This is helpful when disambiguating parsed units. For example, parsing &quot;2w&quot; could be either &quot;2 watts&quot; or &quot;2 weeks&quot;. Specifying only: :duration would return &quot;2 weeks&quot;. Specifying only: :power would return &quot;2 watts&quot; :except is the oppostte of :only . The parsed unit must not match the specified unit or category, or unit categories and units. Returns {:ok, unit} or {:error, {exception, reason}} Notes When both :only and :except options are passed, both conditions must be true in order to return a parsed result. Only units returned by Cldr.Unit.known_units/0 can be used in the :only and :except filters. Examples iex&gt; Cldr.Unit . parse &quot;1kg&quot; Cldr.Unit . new ( 1 , :kilogram ) iex&gt; Cldr.Unit . parse &quot;1w&quot; Cldr.Unit . new ( 1 , :watt ) iex&gt; Cldr.Unit . parse &quot;1w&quot; , only : :duration Cldr.Unit . new ( 1 , :week ) iex&gt; Cldr.Unit . parse &quot;1m&quot; , only : [ :year , :month , :day ] Cldr.Unit . new ( 1 , :month ) iex&gt; Cldr.Unit . parse &quot;1 tages&quot; , locale : &quot;de&quot; Cldr.Unit . new ( 1 , :day ) iex&gt; Cldr.Unit . parse &quot;1 tag&quot; , locale : &quot;de&quot; Cldr.Unit . new ( 1 , :day ) iex&gt; Cldr.Unit . parse ( &quot;42 millispangels&quot; ) { :error , { Cldr.UnknownUnitError , &quot;Unknown unit was detected at \\&quot; spangels \\&quot; &quot; } }","ref":"Cldr.Unit.html#parse/2","title":"Cldr.Unit.parse/2","type":"function"},{"doc":"Parse a string to find a matching unit-atom. This function attempts to parse a string and extract the unit type . The parsed unit type is aliased against all the known unit names for a give locale (or the current locale if no locale is specified). The known aliases for unit types can be returned with MyApp.Cldr.Unit.unit_strings_for/1 where MyApp.Cldr is the name of a backend module. Arguments unit_name_string is any string to be parsed and converted into a unit type options is a keyword list of options Options :locale is any valid locale name returned by Cldr.known_locale_names/0 or a t:Cldr.LanguageTag struct. The default is Cldr.get_locale/0 :backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . :only is a unit category or unit, or a list of unit categories and units. The parsed unit must match one of the categories or units in order to be valid. This is helpful when disambiguating parsed units. For example, parsing &quot;w&quot; could be either watts or :week . Specifying only: :duration would return :week . Specifying only: :power would return :watts :except is the oppostte of :only . The parsed unit must not match the specified unit or category, or unit categories and units. Returns unit_name or raises an exception Notes When both :only and :except options are passed, both conditions must be true in order to return a parsed result. Only units returned by Cldr.Unit.known_units/0 can be used in the :only and :except filters. Examples iex&gt; Cldr.Unit . parse_unit_name! &quot;kg&quot; :kilogram iex&gt; Cldr.Unit . parse_unit_name! &quot;w&quot; :watt iex&gt; Cldr.Unit . parse_unit_name! &quot;w&quot; , only : :duration :week iex&gt; Cldr.Unit . parse_unit_name! &quot;m&quot; , only : [ :year , :month , :day ] :month iex&gt; Cldr.Unit . parse_unit_name! &quot;tages&quot; , locale : &quot;de&quot; :day iex&gt; Cldr.Unit . parse_unit_name! &quot;tag&quot; , locale : &quot;de&quot; :day iex&gt; Cldr.Unit . parse_unit_name! ( &quot;millispangels&quot; ) ** (Cldr.UnknownUnitError) Unknown unit was detected at &quot;spangels&quot;","ref":"Cldr.Unit.html#parse_unit_name!/2","title":"Cldr.Unit.parse_unit_name!/2","type":"function"},{"doc":"Parse a string to find a matching unit-atom. This function attempts to parse a string and extract the unit type . The parsed unit type is aliased against all the known unit names for a give locale (or the current locale if no locale is specified). The known aliases for unit types can be returned with MyApp.Cldr.Unit.unit_strings_for/1 where MyApp.Cldr is the name of a backend module. Arguments unit_name_string is any string to be parsed and converted into a unit type options is a keyword list of options Options :locale is any valid locale name returned by Cldr.known_locale_names/0 or a t:Cldr.LanguageTag struct. The default is Cldr.get_locale/0 :backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . :only is a unit category or unit, or a list of unit categories and units. The parsed unit must match one of the categories or units in order to be valid. This is helpful when disambiguating parsed units. For example, parsing &quot;w&quot; could be either :watt or :weeks . Specifying only: :duration would return :weeks . Specifying only: :power would return :watt :except is the oppostte of :only . The parsed unit must not match the specified unit or category, or unit categories and units. Returns {:ok, unit_name} or {:error, {exception, reason}} Notes When both :only and :except options are passed, both conditions must be true in order to return a parsed result. Only units returned by Cldr.Unit.known_units/0 can be used in the :only and :except filters. Examples iex&gt; Cldr.Unit . parse_unit_name &quot;kg&quot; { :ok , :kilogram } iex&gt; Cldr.Unit . parse_unit_name &quot;w&quot; { :ok , :watt } iex&gt; Cldr.Unit . parse_unit_name &quot;w&quot; , only : :duration { :ok , :week } iex&gt; Cldr.Unit . parse_unit_name &quot;m&quot; , only : [ :year , :month , :day ] { :ok , :month } iex&gt; Cldr.Unit . parse_unit_name &quot;tages&quot; , locale : &quot;de&quot; { :ok , :day } iex&gt; Cldr.Unit . parse_unit_name &quot;tag&quot; , locale : &quot;de&quot; { :ok , :day } iex&gt; Cldr.Unit . parse_unit_name ( &quot;millispangels&quot; ) { :error , { Cldr.UnknownUnitError , &quot;Unknown unit was detected at \\&quot; spangels \\&quot; &quot; } }","ref":"Cldr.Unit.html#parse_unit_name/2","title":"Cldr.Unit.parse_unit_name/2","type":"function"},{"doc":"See Cldr.Unit.Preference.preferred_units!/3 .","ref":"Cldr.Unit.html#preferred_units!/3","title":"Cldr.Unit.preferred_units!/3","type":"function"},{"doc":"See Cldr.Unit.Preference.preferred_units/3 .","ref":"Cldr.Unit.html#preferred_units/3","title":"Cldr.Unit.preferred_units/3","type":"function"},{"doc":"See Cldr.Unit.to_decimal_unit/1 .","ref":"Cldr.Unit.html#ratio_to_decimal/1","title":"Cldr.Unit.ratio_to_decimal/1","type":"function"},{"doc":"See Cldr.Unit.to_float_unit/1 .","ref":"Cldr.Unit.html#ratio_to_float/1","title":"Cldr.Unit.ratio_to_float/1","type":"function"},{"doc":"See Cldr.Unit.Math.round/1 .","ref":"Cldr.Unit.html#round/1","title":"Cldr.Unit.round/1","type":"function"},{"doc":"See Cldr.Unit.Math.round/2 .","ref":"Cldr.Unit.html#round/2","title":"Cldr.Unit.round/2","type":"function"},{"doc":"See Cldr.Unit.Math.round/3 .","ref":"Cldr.Unit.html#round/3","title":"Cldr.Unit.round/3","type":"function"},{"doc":"See Cldr.Unit.known_styles/0 .","ref":"Cldr.Unit.html#styles/0","title":"Cldr.Unit.styles/0","type":"function"},{"doc":"See Cldr.Unit.Math.sub!/2 .","ref":"Cldr.Unit.html#sub!/2","title":"Cldr.Unit.sub!/2","type":"function"},{"doc":"See Cldr.Unit.Math.sub/2 .","ref":"Cldr.Unit.html#sub/2","title":"Cldr.Unit.sub/2","type":"function"},{"doc":"Convert a ratio, float or integer t:Unit to a Decimal t:Unit","ref":"Cldr.Unit.html#to_decimal_unit/1","title":"Cldr.Unit.to_decimal_unit/1","type":"function"},{"doc":"Convert a ratio, Decimal or integer t:Unit to a float t:Unit","ref":"Cldr.Unit.html#to_float_unit/1","title":"Cldr.Unit.to_float_unit/1","type":"function"},{"doc":"Formats a number into a string according to a unit definition for the current process's locale and backend or raises on error. The current process's locale is set with Cldr.put_locale/1 . See Cldr.Unit.to_string!/3 for full details.","ref":"Cldr.Unit.html#to_string!/1","title":"Cldr.Unit.to_string!/1","type":"function"},{"doc":"Formats a number into a string according to a unit definition for the current process's locale and backend or raises on error. During processing any :format_options of a t:Cldr.Unit are merged with options with options taking precedence. Arguments number is any number (integer, float or Decimal) or a t:Cldr.Unit struct backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . options is a keyword list Options :unit is any unit returned by Cldr.Unit.known_units/0 . Ignored if the number to be formatted is a t:Cldr.Unit struct :locale is any valid locale name returned by Cldr.known_locale_names/0 or a Cldr.LanguageTag struct. The default is Cldr.get_locale/0 :style is one of those returned by Cldr.Unit.known_styles/0 . The current styles are :long , :short and :narrow . The default is style: :long Any other options are passed to Cldr.Number.to_string/2 which is used to format the number Returns formatted_string or raises an exception Examples iex&gt; Cldr.Unit . to_string! Cldr.Unit . new! ( :gallon , 123 ) , MyApp.Cldr &quot;123 gallons&quot; iex&gt; Cldr.Unit . to_string! Cldr.Unit . new! ( :gallon , 1 ) , MyApp.Cldr &quot;1 gallon&quot; iex&gt; Cldr.Unit . to_string! Cldr.Unit . new! ( :gallon , 1 ) , MyApp.Cldr , locale : &quot;af&quot; &quot;1 gelling&quot;","ref":"Cldr.Unit.html#to_string!/3","title":"Cldr.Unit.to_string!/3","type":"function"},{"doc":"Formats a number into a string according to a unit definition for the current process's locale and backend. The current process's locale is set with Cldr.put_locale/1 . See Cldr.Unit.to_string/3 for full details.","ref":"Cldr.Unit.html#to_string/1","title":"Cldr.Unit.to_string/1","type":"function"},{"doc":"Formats a number into a string according to a unit definition for a locale. During processing any :format_options of a Unit.t() are merged with options with options taking precedence. Arguments list_or_number is any number (integer, float or Decimal) or a t:Cldr.Unit struct or a list of t:Cldr.Unit structs backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . options is a keyword list of options. Options :unit is any unit returned by Cldr.Unit.known_units/0 . Ignored if the number to be formatted is a t:Cldr.Unit struct :locale is any valid locale name returned by Cldr.known_locale_names/1 or a Cldr.LanguageTag struct. The default is Cldr.get_locale/0 style is one of those returned by Cldr.Unit.styles . The current styles are :long , :short and :narrow . The default is style: :long :grammatical_case indicates that a localisation for the given locale and given grammatical case should be used. See Cldr.Unit.known_grammatical_cases/0 for the list of known grammatical cases. Note that not all locales define all cases. However all locales do define the :nominative case, which is also the default. :gender indicates that a localisation for the given locale and given grammatical gender should be used. See Cldr.Unit.known_grammatical_genders/0 for the list of known grammatical genders. Note that not all locales define all genders. :list_options is a keyword list of options for formatting a list which is passed through to Cldr.List.to_string/3 . This is only applicable when formatting a list of units. Any other options are passed to Cldr.Number.to_string/2 which is used to format the number Returns {:ok, formatted_string} or {:error, {exception, message}} Examples iex&gt; Cldr.Unit . to_string Cldr.Unit . new! ( :gallon , 123 ) , MyApp.Cldr { :ok , &quot;123 gallons&quot; } iex&gt; Cldr.Unit . to_string Cldr.Unit . new! ( :gallon , 1 ) , MyApp.Cldr { :ok , &quot;1 gallon&quot; } iex&gt; Cldr.Unit . to_string Cldr.Unit . new! ( :gallon , 1 ) , MyApp.Cldr , locale : &quot;af&quot; { :ok , &quot;1 gelling&quot; } iex&gt; Cldr.Unit . to_string Cldr.Unit . new! ( :gallon , 1 ) , MyApp.Cldr , locale : &quot;bs&quot; { :ok , &quot;1 galon&quot; } iex&gt; Cldr.Unit . to_string Cldr.Unit . new! ( :gallon , 1234 ) , MyApp.Cldr , format : :long { :ok , &quot;1 thousand gallons&quot; } iex&gt; Cldr.Unit . to_string Cldr.Unit . new! ( :gallon , 1234 ) , MyApp.Cldr , format : :short { :ok , &quot;1K gallons&quot; } iex&gt; Cldr.Unit . to_string Cldr.Unit . new! ( :megahertz , 1234 ) , MyApp.Cldr { :ok , &quot;1,234 megahertz&quot; } iex&gt; Cldr.Unit . to_string Cldr.Unit . new! ( :megahertz , 1234 ) , MyApp.Cldr , style : :narrow { :ok , &quot;1,234MHz&quot; } iex&gt; unit = Cldr.Unit . new! ( 123 , :foot ) iex&gt; Cldr.Unit . to_string unit , MyApp.Cldr { :ok , &quot;123 feet&quot; } iex&gt; Cldr.Unit . to_string 123 , MyApp.Cldr , unit : :foot { :ok , &quot;123 feet&quot; } iex&gt; Cldr.Unit . to_string Decimal . new ( 123 ) , MyApp.Cldr , unit : :foot { :ok , &quot;123 feet&quot; } iex&gt; Cldr.Unit . to_string 123 , MyApp.Cldr , unit : :megabyte , locale : &quot;en&quot; , style : :unknown { :error , { Cldr.UnknownFormatError , &quot;The unit style :unknown is not known.&quot; } }","ref":"Cldr.Unit.html#to_string/3","title":"Cldr.Unit.to_string/3","type":"function"},{"doc":"See Cldr.Unit.known_units/0 .","ref":"Cldr.Unit.html#unit/0","title":"Cldr.Unit.unit/0","type":"function"},{"doc":"See Cldr.Unit.known_unit_categories/0 .","ref":"Cldr.Unit.html#unit_categories/0","title":"Cldr.Unit.unit_categories/0","type":"function"},{"doc":"Returns the units category for a given unit Options unit is any unit returned by Cldr.Unit.new/2 Returns {:ok, category} or {:error, {exception, message}} Examples iex&gt; Cldr.Unit . unit_category :pint_metric { :ok , :volume } iex&gt; Cldr.Unit . unit_category :stone { :ok , :mass } iex&gt; Cldr.Unit . unit_category :watt { :ok , :power } iex&gt; Cldr.Unit . unit_category &quot;kilowatt hour&quot; { :ok , :energy } iex&gt; Cldr.Unit . unit_category &quot;watt hour per light year&quot; { :error , { Cldr.Unit.UnknownCategoryError , &quot;The category for \\&quot; watt hour per light year \\&quot; is not known.&quot; } }","ref":"Cldr.Unit.html#unit_category/1","title":"Cldr.Unit.unit_category/1","type":"function"},{"doc":"Returns a mapping between Unit categories and the uses they define. Example iex&gt; Cldr.Unit . unit_category_usage %{ area : [ :default , :geograph , :land ] , concentration : [ :blood_glucose , :default ] , consumption : [ :default , :vehicle_fuel ] , duration : [ :default , :media ] , energy : [ :default , :food ] , length : [ :default , :focal_length , :person , :person_height , :rainfall , :road , :snowfall , :vehicle , :visiblty ] , mass : [ :default , :person ] , mass_density : [ :default ] , power : [ :default , :engine ] , pressure : [ :baromtrc , :default ] , speed : [ :default , :wind ] , temperature : [ :default , :weather ] , volume : [ :default , :fluid , :oil , :vehicle ] , year_duration : [ :default , :person_age ] }","ref":"Cldr.Unit.html#unit_category_usage/0","title":"Cldr.Unit.unit_category_usage/0","type":"function"},{"doc":"","ref":"Cldr.Unit.html#unit_type/1","title":"Cldr.Unit.unit_type/1","type":"function"},{"doc":"Validates a grammatical case and normalizes it to a standard downcased atom form","ref":"Cldr.Unit.html#validate_grammatical_case/1","title":"Cldr.Unit.validate_grammatical_case/1","type":"function"},{"doc":"Validates a grammatical gender and normalizes it to a standard downcased atom form","ref":"Cldr.Unit.html#validate_grammatical_gender/2","title":"Cldr.Unit.validate_grammatical_gender/2","type":"function"},{"doc":"Validates a unit style and normalizes it to a standard downcased atom form","ref":"Cldr.Unit.html#validate_style/1","title":"Cldr.Unit.validate_style/1","type":"function"},{"doc":"Validates a unit name and normalizes it, A unit name can be expressed as: an atom() in which case the unit must be localizable in CLDR directly or a t:String in which case it is parsed into a list of composable subunits that can be converted but are not guaranteed to be output as a localized string. Arguments unit_name is an atom() or t:String , supplied as is or as part of an t:Cldr.Unit struct. Returns {:ok, canonical_unit_name, conversion} where canonical_unit_name is the normalized unit name and conversion is an opaque structure used to convert this this unit into its base unit or {:error, {exception, reason}} Notes A returned unit_name that is an atom is directly localisable (CLDR has translation data for the unit). A unit_name that is a t:String is composed of one or more unit names that need to be resolved in order for the unit_name to be localised. The difference is an implementation detail and should not be of concern to the user of this library. Examples iex&gt; Cldr.Unit . validate_unit :meter { :ok , :meter , [ meter : % Cldr.Unit.Conversion { base_unit : [ :meter ] , factor : 1 , offset : 0 } ] } iex&gt; Cldr.Unit . validate_unit &quot;meter&quot; { :ok , :meter , [ meter : % Cldr.Unit.Conversion { base_unit : [ :meter ] , factor : 1 , offset : 0 } ] } iex&gt; Cldr.Unit . validate_unit &quot;miles_per_liter&quot; { :error , { Cldr.UnknownUnitError , &quot;Unknown unit was detected at \\&quot; s \\&quot; &quot; } } iex&gt; Cldr.Unit . validate_unit &quot;mile_per_liter&quot; { :ok , &quot;mile_per_liter&quot; , { [ mile : % Cldr.Unit.Conversion { base_unit : [ :meter ] , factor : Ratio . new ( 905980129838867985 , 562949953421312 ) , offset : 0 } ] , [ liter : % Cldr.Unit.Conversion { base_unit : [ :cubic_meter ] , factor : Ratio . new ( 1152921504606847 , 1152921504606846976 ) , offset : 0 } ] } }","ref":"Cldr.Unit.html#validate_unit/1","title":"Cldr.Unit.validate_unit/1","type":"function"},{"doc":"Return the value of the Unit struct Arguments unit is any unit returned by Cldr.Unit.new/2 Returns an integer, float or Decimal representing the amount of the unit Example iex&gt; Cldr.Unit . value Cldr.Unit . new! ( :kilogram , 23 ) 23","ref":"Cldr.Unit.html#value/1","title":"Cldr.Unit.value/1","type":"function"},{"doc":"Returns a new unit of the same unit type but with a zero value. Argument unit is any unit returned by Cldr.Unit.new/2 Example iex&gt; u = Cldr.Unit . new! ( :foot , 23.3 ) # Cldr.Unit &lt; :foot , 23.3 &gt; iex&gt; Cldr.Unit . zero ( u ) # Cldr.Unit &lt; :foot , 0.0 &gt;","ref":"Cldr.Unit.html#zero/1","title":"Cldr.Unit.zero/1","type":"function"},{"doc":"Returns a boolean indicating whether a given unit has a zero value. Argument unit is any unit returned by Cldr.Unit.new/2 Examples iex&gt; u = Cldr.Unit . new! ( :foot , 23.3 ) # Cldr.Unit &lt; :foot , 23.3 &gt; iex&gt; Cldr.Unit . zero? ( u ) false iex&gt; u = Cldr.Unit . new! ( :foot , 0 ) # Cldr.Unit &lt; :foot , 0 &gt; iex&gt; Cldr.Unit . zero? ( u ) true","ref":"Cldr.Unit.html#zero?/1","title":"Cldr.Unit.zero?/1","type":"function"},{"doc":"","ref":"Cldr.Unit.html#t:base_conversion/0","title":"Cldr.Unit.base_conversion/0","type":"type"},{"doc":"","ref":"Cldr.Unit.html#t:category/0","title":"Cldr.Unit.category/0","type":"type"},{"doc":"","ref":"Cldr.Unit.html#t:conversion/0","title":"Cldr.Unit.conversion/0","type":"type"},{"doc":"","ref":"Cldr.Unit.html#t:grammatical_case/0","title":"Cldr.Unit.grammatical_case/0","type":"type"},{"doc":"","ref":"Cldr.Unit.html#t:grammatical_gender/0","title":"Cldr.Unit.grammatical_gender/0","type":"type"},{"doc":"","ref":"Cldr.Unit.html#t:locale/0","title":"Cldr.Unit.locale/0","type":"type"},{"doc":"","ref":"Cldr.Unit.html#t:measurement_system/0","title":"Cldr.Unit.measurement_system/0","type":"type"},{"doc":"","ref":"Cldr.Unit.html#t:measurement_system_key/0","title":"Cldr.Unit.measurement_system_key/0","type":"type"},{"doc":"","ref":"Cldr.Unit.html#t:style/0","title":"Cldr.Unit.style/0","type":"type"},{"doc":"","ref":"Cldr.Unit.html#t:t/0","title":"Cldr.Unit.t/0","type":"type"},{"doc":"","ref":"Cldr.Unit.html#t:translatable_unit/0","title":"Cldr.Unit.translatable_unit/0","type":"type"},{"doc":"","ref":"Cldr.Unit.html#t:unit/0","title":"Cldr.Unit.unit/0","type":"type"},{"doc":"","ref":"Cldr.Unit.html#t:usage/0","title":"Cldr.Unit.usage/0","type":"type"},{"doc":"","ref":"Cldr.Unit.html#t:value/0","title":"Cldr.Unit.value/0","type":"type"},{"doc":"Additional domain-specific units can be defined to suit application requirements. In the context of ex_cldr there are two parts of configuring additional units. Configure the unit, base unit and conversion in config.exs . This is a requirement since units are compiled into code. Configure the localizations for the additional unit in a CLDR backend module. Once configured, additional units act and behave like any of the predefined units of measure defined by CLDR. Configuring a unit in config.exs Under the application :ex_cldr_units define a key :additional_units with the required unit definitions. For example: config :ex_cldr_units , :additional_units , vehicle : [ base_unit : :unit , factor : 1 , offset : 0 , sort_before : :all ] , person : [ base_unit : :unit , factor : 1 , offset : 0 , sort_before : :all ] This example defines two additional units: :vehicle and :person . The keys :base_unit , and :factor are required. The key :offset is optional and defaults to 0 . The key :sort_before is optional and defaults to :none . Configuration keys :base_unit is the common denominator that is used to support conversion between like units. It can be any atom value. For example :liter is the base unit for volume units, :meter is the base unit for length units. :factor is used to convert a unit to its base unit in order to support conversion. When converting a unit to another compatible unit, the unit is first multiplied by this units factor then divided by the target units factor. :offset is added to a unit after applying its base factor in order to convert to another unit. :sort_before determines where in this base unit sorts relative to other base units. Typically this is set to :all in which case this base unit sorts before all other base units or :none in which case this base unit sorted after all other base units. The default is :none . If in doubt, leave this key to its default. :systems is list of measurement systems to which this unit belongs. The known measurement systems are :metric , :uksystem and :ussystem . The default is [:metric, :ussystem, :uksystem] . Defining localizations Localizations are defined in a backend module through adding use Cldr.Unit.Additional to the top of the backend module and invoking Cldr.Unit.Additional.unit_localization/4 for each localization. See Cldr.Unit.Additional.unit_localization/4 for further information. Note that one invocation of the macro is required for each combination of locale, style and unit. An exception will be raised at runtime is a localization is expected but is not found.","ref":"Cldr.Unit.Additional.html","title":"Cldr.Unit.Additional","type":"module"},{"doc":"","ref":"Cldr.Unit.Additional.html#merge_base_units/3","title":"Cldr.Unit.Additional.merge_base_units/3","type":"function"},{"doc":"Although defining a unit in config.exs is enough to create, operate on and serialize an additional unit, it cannot be localised without defining localizations in an ex_cldr backend module. For example: defmodule MyApp.Cldr do use Cldr.Unit.Additional use Cldr , locales : [ &quot;en&quot; , &quot;fr&quot; , &quot;de&quot; , &quot;bs&quot; , &quot;af&quot; , &quot;af-NA&quot; , &quot;se-SE&quot; ] , default_locale : &quot;en&quot; , providers : [ Cldr.Number , Cldr.Unit , Cldr.List ] unit_localization ( :person , &quot;en&quot; , :long , one : &quot;{0} person&quot; , other : &quot;{0} people&quot; , display_name : &quot;people&quot; ) unit_localization ( :person , &quot;en&quot; , :short , one : &quot;{0} per&quot; , other : &quot;{0} pers&quot; , display_name : &quot;people&quot; ) unit_localization ( :person , &quot;en&quot; , :narrow , one : &quot;{0} p&quot; , other : &quot;{0} p&quot; , display_name : &quot;p&quot; ) end Note the additions to a typical ex_cldr backend module: use Cldr.Unit.Additional is required to define additional units use of the unit_localization/4 macro in order to define a localization. One invocation of unit_localization should made for each combination of unit, locale and style. Parameters to unit_localization/4 unit is the name of the additional unit as an atom . locale is the locale name for this localization. It should be one of the locale configured in this backend although this cannot currently be confirmed at compile time. style is one of :long , :short , or :narrow . localizations is a keyword like of localization strings. Two keys - :display_name and :other are mandatory. They represent the localizations for a non-count display name and :other is the localization for a unit when no other pluralization is defined. Localisations Localization keyword list defines localizations that match the plural rules for a given locale. Plural rules for a given number in a given locale resolve to one of six keys: :zero :one (singular) :two (dual) :few (paucal) :many (also used for fractions if they have a separate class) :other (required—general plural form—also used if the language only has a single form) Only the :other key is required. For english, providing keys for :one and :other is enough. Other languages have different grammatical requirements. The key :display_name is used by the function Cldr.Unit.display_name/1 which is primarily used to support UI applications.","ref":"Cldr.Unit.Additional.html#unit_localization/4","title":"Cldr.Unit.Additional.unit_localization/4","type":"macro"},{"doc":"Functions to manage unit name aliases","ref":"Cldr.Unit.Alias.html","title":"Cldr.Unit.Alias","type":"module"},{"doc":"Un-aliases the provided unit if there is one or return the argument unchanged.","ref":"Cldr.Unit.Alias.html#alias/1","title":"Cldr.Unit.Alias.alias/1","type":"function"},{"doc":"","ref":"Cldr.Unit.Alias.html#aliases/0","title":"Cldr.Unit.Alias.aliases/0","type":"function"},{"doc":"","ref":"Cldr.Unit.Backend.html","title":"Cldr.Unit.Backend","type":"module"},{"doc":"","ref":"Cldr.Unit.Backend.html#define_unit_module/1","title":"Cldr.Unit.Backend.define_unit_module/1","type":"function"},{"doc":"Functions to support the base unit calculations for a unit. Base unit equality is used to determine whether a one unit can be converted to another","ref":"Cldr.Unit.BaseUnit.html","title":"Cldr.Unit.BaseUnit","type":"module"},{"doc":"Returns the canonical base unit name for a unit. The base unit is the common unit through which conversions are passed. Arguments unit_string is any string representing a unit such as light_year_per_week . Returns canonical_base_unit or raises an exception Examples iex&gt; Cldr.Unit.Parser . canonical_base_unit! &quot;meter&quot; :meter iex&gt; Cldr.Unit.Parser . canonical_base_unit! &quot;meter meter&quot; :square_meter iex&gt; Cldr.Unit.Parser . canonical_base_unit! &quot;meter per kilogram&quot; &quot;meter_per_kilogram&quot; iex&gt; Cldr.Unit.Parser . canonical_base_unit! &quot;yottagram per mile scandinavian&quot; &quot;kilogram_per_meter&quot;","ref":"Cldr.Unit.BaseUnit.html#canonical_base_unit!/1","title":"Cldr.Unit.BaseUnit.canonical_base_unit!/1","type":"function"},{"doc":"Returns the canonical base unit name for a unit. The base unit is the common unit through which conversions are passed. Arguments unit_string is any string representing a unit such as light_year_per_week . Returns {:ok, canonical_base_unit} or {:error, {exception, reason}} Examples iex&gt; Cldr.Unit.Parser . canonical_base_unit &quot;meter&quot; { :ok , :meter } iex&gt; Cldr.Unit.Parser . canonical_base_unit &quot;meter meter&quot; { :ok , :square_meter } iex&gt; Cldr.Unit.Parser . canonical_base_unit &quot;meter per kilogram&quot; { :ok , &quot;meter_per_kilogram&quot; } iex&gt; Cldr.Unit.Parser . canonical_base_unit &quot;yottagram per mile scandinavian&quot; { :ok , &quot;kilogram_per_meter&quot; }","ref":"Cldr.Unit.BaseUnit.html#canonical_base_unit/1","title":"Cldr.Unit.BaseUnit.canonical_base_unit/1","type":"function"},{"doc":"","ref":"Cldr.Unit.BaseUnit.html#do_canonical_base_unit/1","title":"Cldr.Unit.BaseUnit.do_canonical_base_unit/1","type":"function"},{"doc":"Unit conversion functions for the units defined in Cldr .","ref":"Cldr.Unit.Conversion.html","title":"Cldr.Unit.Conversion","type":"module"},{"doc":"Returns the base unit and the base unit conversionfor a given unit. Argument unit is either a t:Cldr.Unit , an atom or a t:String Returns {:ok, base_unit, conversion} or {:error, {exception, reason}} Example iex&gt; Cldr.Unit.Conversion . base_unit_and_conversion :square_kilometer { :ok , :square_meter , [ square_kilometer : % Cldr.Unit.Conversion { base_unit : [ :square , :meter ] , factor : 1000000 , offset : 0 } ] } iex&gt; Cldr.Unit.Conversion . base_unit_and_conversion :square_table { :error , { Cldr.UnknownUnitError , &quot;Unknown unit was detected at \\&quot; table \\&quot; &quot; } }","ref":"Cldr.Unit.Conversion.html#base_unit_and_conversion/1","title":"Cldr.Unit.Conversion.base_unit_and_conversion/1","type":"function"},{"doc":"Returns the conversion that calculates the base unit into another unit or and error.","ref":"Cldr.Unit.Conversion.html#conversion_for/2","title":"Cldr.Unit.Conversion.conversion_for/2","type":"function"},{"doc":"Convert one unit into another unit of the same unit type (length, volume, mass, ...) and raises on a unit type mismatch Arguments unit is any unit returned by Cldr.Unit.new/2 to_unit is any unit name returned by Cldr.Unit.known_units/0 Returns a Unit.t of the unit type to_unit or raises an exception Examples iex&gt; Cldr.Unit.Conversion . convert! ( Cldr.Unit . new! ( :celsius , 0 ) , :fahrenheit ) ...&gt; |&gt; Cldr.Unit . round # Cldr.Unit &lt; :fahrenheit , 32.0 &gt; iex&gt; Cldr.Unit.Conversion . convert! ( Cldr.Unit . new! ( :fahrenheit , 32 ) , :celsius ) ...&gt; |&gt; Cldr.Unit . round # Cldr.Unit &lt; :celsius , 0.0 &gt; Cldr.Unit.Conversion . convert Cldr.Unit . new! ( :mile , 1 ) , :gallon ** (Cldr.Unit.IncompatibleUnitsError) Operations can only be performed between units of the same type. Received :mile and :gallon","ref":"Cldr.Unit.Conversion.html#convert!/2","title":"Cldr.Unit.Conversion.convert!/2","type":"function"},{"doc":"Convert one unit into another unit of the same unit type (length, volume, mass, ...) Arguments unit is any unit returned by Cldr.Unit.new/2 to_unit is any unit name returned by Cldr.Unit.known_units/0 Returns a Unit.t of the unit type to_unit or {:error, {exception, message}} Examples iex&gt; Cldr.Unit . convert Cldr.Unit . new! ( :mile , 1 ) , :foot { :ok , Cldr.Unit . new! ( :foot , 5280 ) } iex&gt; Cldr.Unit . convert Cldr.Unit . new! ( :mile , 1 ) , :gallon { :error , { Cldr.Unit.IncompatibleUnitsError , &quot;Operations can only be performed between units with the same base unit. Received :mile and :gallon&quot; } }","ref":"Cldr.Unit.Conversion.html#convert/2","title":"Cldr.Unit.Conversion.convert/2","type":"function"},{"doc":"Convert a unit into its base unit and raises on error For example, the base unit for length is meter . The base unit is an intermediary unit used in all conversions. Arguments unit is any unit returned by Cldr.Unit.new/2 Returns unit converted to its base unit as a t:Unit.t() or raises an exception Example iex&gt; unit = Cldr.Unit . new! ( :kilometer , 10 ) iex&gt; Cldr.Unit.Conversion . convert_to_base_unit! unit # Cldr.Unit &lt; :meter , 10000 &gt;","ref":"Cldr.Unit.Conversion.html#convert_to_base_unit!/1","title":"Cldr.Unit.Conversion.convert_to_base_unit!/1","type":"function"},{"doc":"Convert a unit into its base unit. For example, the base unit for length is meter . The base unit is an intermediary unit used in all conversions. Arguments unit is any unit returned by Cldr.Unit.new/2 Returns unit converted to its base unit as a t:Unit.t() or {;error, {exception, reason}} as an error Example iex&gt; unit = Cldr.Unit . new! ( :kilometer , 10 ) iex&gt; Cldr.Unit.Conversion . convert_to_base_unit unit { :ok , Cldr.Unit . new! ( :meter , 10000 ) }","ref":"Cldr.Unit.Conversion.html#convert_to_base_unit/1","title":"Cldr.Unit.Conversion.convert_to_base_unit/1","type":"function"},{"doc":"","ref":"Cldr.Unit.Conversion.html#maybe_invert_value/2","title":"Cldr.Unit.Conversion.maybe_invert_value/2","type":"function"},{"doc":"","ref":"Cldr.Unit.Conversion.html#t:factor/0","title":"Cldr.Unit.Conversion.factor/0","type":"type"},{"doc":"","ref":"Cldr.Unit.Conversion.html#t:offset/0","title":"Cldr.Unit.Conversion.offset/0","type":"type"},{"doc":"","ref":"Cldr.Unit.Conversion.html#t:t/0","title":"Cldr.Unit.Conversion.t/0","type":"type"},{"doc":"Options structure for unit conversions","ref":"Cldr.Unit.Conversion.Options.html","title":"Cldr.Unit.Conversion.Options","type":"module"},{"doc":"","ref":"Cldr.Unit.Conversion.Options.html#t:t/0","title":"Cldr.Unit.Conversion.Options.t/0","type":"type"},{"doc":"","ref":"Cldr.Unit.Format.html","title":"Cldr.Unit.Format","type":"module"},{"doc":"Traverses the components of a unit and resolves a list of base units with their gramatical case and plural selector definitions for a given locale. This function relies upon the internal representation of units and grammatical features and is primarily for the support of formatting a function through Cldr.Unit.to_string/2 . Arguments unit is a t:Cldr.Unit or a binary unit string Options :locale is any valid locale name returned by Cldr.known_locale_names/1 or a t:Cldr.LanguageTag struct. The default is Cldr.get_locale/0 backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . Returns Examples","ref":"Cldr.Unit.Format.html#grammar/2","title":"Cldr.Unit.Format.grammar/2","type":"function"},{"doc":"Formats a number into an iolist according to a unit definition for the current process's locale and backend. The current process's locale is set with Cldr.put_locale/1 . See Cldr.Unit.Format.to_iolist!/3 for full details.","ref":"Cldr.Unit.Format.html#to_iolist!/1","title":"Cldr.Unit.Format.to_iolist!/1","type":"function"},{"doc":"Formats a unit using to_iolist/3 but raises if there is an error. Arguments list_or_number is any number (integer, float or Decimal) or a t:Cldr.Unit struct or a list of t:Cldr.Unit structs options is a keyword list Options :unit is any unit returned by Cldr.Unit.known_units/0 . Ignored if the number to be formatted is a t:Cldr.Unit struct :locale is any valid locale name returned by Cldr.known_locale_names/0 or a Cldr.LanguageTag struct. The default is Cldr.get_locale/0 :style is one of those returned by Cldr.Unit.known_styles/0 . The current styles are :long , :short and :narrow . The default is style: :long . :grammatical_case indicates that a localisation for the given locale and given grammatical case should be used. See Cldr.Unit.known_grammatical_cases/0 for the list of known grammatical cases. Note that not all locales define all cases. However all locales do define the :nominative case, which is also the default. :gender indicates that a localisation for the given locale and given grammatical gender should be used. See Cldr.Unit.known_grammatical_genders/0 for the list of known grammatical genders. Note that not all locales define all genders. :list_options is a keyword list of options for formatting a list which is passed through to Cldr.List.to_string/3 . This is only applicable when formatting a list of units. Any other options are passed to Cldr.Number.to_string/2 which is used to format the number Returns io_list or raises an exception Examples iex&gt; Cldr.Unit.Format . to_iolist! 123 , unit : :gallon [ &quot;123&quot; , &quot; gallons&quot; ]","ref":"Cldr.Unit.Format.html#to_iolist!/3","title":"Cldr.Unit.Format.to_iolist!/3","type":"function"},{"doc":"Formats a number into an iolist according to a unit definition for the current process's locale and backend. The current process's locale is set with Cldr.put_locale/1 . See Cldr.Unit.Format.to_iolist/3 for full details.","ref":"Cldr.Unit.Format.html#to_iolist/1","title":"Cldr.Unit.Format.to_iolist/1","type":"function"},{"doc":"Formats a number into an iolist according to a unit definition for a locale. Arguments list_or_number is any number (integer, float or Decimal) or a t:Cldr.Unit struct or a list of t:Cldr.Unit structs options is a keyword list Options :unit is any unit returned by Cldr.Unit.known_units/0 . Ignored if the number to be formatted is a t:Cldr.Unit struct :locale is any valid locale name returned by Cldr.known_locale_names/0 or a Cldr.LanguageTag struct. The default is Cldr.get_locale/0 :style is one of those returned by Cldr.Unit.available_styles . The current styles are :long , :short and :narrow . The default is style: :long :grammatical_case indicates that a localisation for the given locale and given grammatical case should be used. See Cldr.Unit.known_grammatical_cases/0 for the list of known grammatical cases. Note that not all locales define all cases. However all locales do define the :nominative case, which is also the default. :gender indicates that a localisation for the given locale and given grammatical gender should be used. See Cldr.Unit.known_grammatical_genders/0 for the list of known grammatical genders. Note that not all locales define all genders. :list_options is a keyword list of options for formatting a list which is passed through to Cldr.List.to_string/3 . This is only applicable when formatting a list of units. Any other options are passed to Cldr.Number.to_string/2 which is used to format the number Returns {:ok, io_list} or {:error, {exception, message}} Examples iex&gt; Cldr.Unit.Format . to_iolist Cldr.Unit . new! ( :gallon , 123 ) { :ok , [ &quot;123&quot; , &quot; gallons&quot; ] }","ref":"Cldr.Unit.Format.html#to_iolist/3","title":"Cldr.Unit.Format.to_iolist/3","type":"function"},{"doc":"Formats a number into a string according to a unit definition for the current process's locale and backend or raises on error. The current process's locale is set with Cldr.put_locale/1 . See Cldr.Unit.to_string!/3 for full details.","ref":"Cldr.Unit.Format.html#to_string!/1","title":"Cldr.Unit.Format.to_string!/1","type":"function"},{"doc":"Formats a number into a string according to a unit definition for the current process's locale and backend or raises on error. During processing any :format_options of a t:Cldr.Unit are merged with options with options taking precedence. Arguments number is any number (integer, float or Decimal) or a t:Cldr.Unit struct backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . options is a keyword list Options :unit is any unit returned by Cldr.Unit.known_units/0 . Ignored if the number to be formatted is a t:Cldr.Unit struct :locale is any valid locale name returned by Cldr.known_locale_names/0 or a Cldr.LanguageTag struct. The default is Cldr.get_locale/0 :style is one of those returned by Cldr.Unit.available_styles . The current styles are :long , :short and :narrow . The default is style: :long Any other options are passed to Cldr.Number.to_string/2 which is used to format the number Returns formatted_string or raises an exception Examples iex&gt; Cldr.Unit.Format . to_string! Cldr.Unit . new! ( :gallon , 123 ) , MyApp.Cldr &quot;123 gallons&quot; iex&gt; Cldr.Unit.Format . to_string! Cldr.Unit . new! ( :gallon , 1 ) , MyApp.Cldr &quot;1 gallon&quot; iex&gt; Cldr.Unit.Format . to_string! Cldr.Unit . new! ( :gallon , 1 ) , MyApp.Cldr , locale : &quot;af&quot; &quot;1 gelling&quot;","ref":"Cldr.Unit.Format.html#to_string!/3","title":"Cldr.Unit.Format.to_string!/3","type":"function"},{"doc":"Formats a number into a string according to a unit definition for the current process's locale and backend. The current process's locale is set with Cldr.put_locale/1 . See Cldr.Unit.to_string/3 for full details.","ref":"Cldr.Unit.Format.html#to_string/1","title":"Cldr.Unit.Format.to_string/1","type":"function"},{"doc":"Formats a number into a string according to a unit definition for a locale. During processing any :format_options of a Unit.t() are merged with options with options taking precedence. Arguments list_or_number is any number (integer, float or Decimal) or a t:Cldr.Unit struct or a list of t:Cldr.Unit structs backend is any module that includes use Cldr and therefore is a Cldr backend module. The default is Cldr.default_backend!/0 . options is a keyword list of options. Options :unit is any unit returned by Cldr.Unit.known_units/0 . Ignored if the number to be formatted is a t:Cldr.Unit struct :locale is any valid locale name returned by Cldr.known_locale_names/1 or a Cldr.LanguageTag struct. The default is Cldr.get_locale/0 style is one of those returned by Cldr.Unit.known_styles/0 . The current styles are :long , :short and :narrow . The default is style: :long :grammatical_case indicates that a localisation for the given locale and given grammatical case should be used. See Cldr.Unit.known_grammatical_cases/0 for the list of known grammatical cases. Note that not all locales define all cases. However all locales do define the :nominative case, which is also the default. :gender indicates that a localisation for the given locale and given grammatical gender should be used. See Cldr.Unit.known_grammatical_genders/0 for the list of known grammatical genders. Note that not all locales define all genders. :list_options is a keyword list of options for formatting a list which is passed through to Cldr.List.to_string/3 . This is only applicable when formatting a list of units. Any other options are passed to Cldr.Number.to_string/2 which is used to format the number Returns {:ok, formatted_string} or {:error, {exception, message}} Examples iex&gt; Cldr.Unit.Format . to_string Cldr.Unit . new! ( :gallon , 123 ) , MyApp.Cldr { :ok , &quot;123 gallons&quot; } iex&gt; Cldr.Unit.Format . to_string Cldr.Unit . new! ( :gallon , 1 ) , MyApp.Cldr { :ok , &quot;1 gallon&quot; } iex&gt; Cldr.Unit.Format . to_string Cldr.Unit . new! ( :gallon , 1 ) , MyApp.Cldr , locale : &quot;af&quot; { :ok , &quot;1 gelling&quot; } iex&gt; Cldr.Unit.Format . to_string Cldr.Unit . new! ( :gallon , 1 ) , MyApp.Cldr , locale : &quot;bs&quot; { :ok , &quot;1 galon&quot; } iex&gt; Cldr.Unit.Format . to_string Cldr.Unit . new! ( :gallon , 1234 ) , MyApp.Cldr , format : :long { :ok , &quot;1 thousand gallons&quot; } iex&gt; Cldr.Unit.Format . to_string Cldr.Unit . new! ( :gallon , 1234 ) , MyApp.Cldr , format : :short { :ok , &quot;1K gallons&quot; } iex&gt; Cldr.Unit.Format . to_string Cldr.Unit . new! ( :megahertz , 1234 ) , MyApp.Cldr { :ok , &quot;1,234 megahertz&quot; } iex&gt; Cldr.Unit.Format . to_string Cldr.Unit . new! ( :megahertz , 1234 ) , MyApp.Cldr , style : :narrow { :ok , &quot;1,234MHz&quot; } iex&gt; Cldr.Unit.Format . to_string Cldr.Unit . new! ( 123 , :foot ) , MyApp.Cldr { :ok , &quot;123 feet&quot; } iex&gt; Cldr.Unit.Format . to_string 123 , MyApp.Cldr , unit : :foot { :ok , &quot;123 feet&quot; } iex&gt; Cldr.Unit.Format . to_string Decimal . new ( 123 ) , MyApp.Cldr , unit : :foot { :ok , &quot;123 feet&quot; } iex&gt; Cldr.Unit . to_string Cldr.Unit . new! ( 2 , &quot;curr-usd-per-gallon&quot; ) , MyApp.Cldr { :ok , &quot;$2.00 per gallon&quot; } iex&gt; Cldr.Unit . to_string Cldr.Unit . new! ( 2 , &quot;gallon-per-curr-usd&quot; ) , MyApp.Cldr { :ok , &quot;2 gallons per US dollar&quot; } iex&gt; Cldr.Unit.Format . to_string 123 , MyApp.Cldr , unit : :megabyte , locale : &quot;en&quot; , style : :unknown { :error , { Cldr.UnknownFormatError , &quot;The unit style :unknown is not known.&quot; } } iex&gt; Cldr.Unit.Format . to_string 123 , MyApp.Cldr , unit : :megabyte , locale : &quot;en&quot; , ...&gt; grammatical_gender : :feminine { :error , { Cldr.UnknownGrammaticalGenderError , &quot;The locale :en does not define a grammatical gender :feminine. The valid genders are [:masculine]&quot; } }","ref":"Cldr.Unit.Format.html#to_string/3","title":"Cldr.Unit.Format.to_string/3","type":"function"},{"doc":"Traverses a unit's decomposition and invokes a function on each node of the composition tree. Arguments unit is any unit returned by Cldr.Unit.new/2 fun is any single-arity function. It will be invoked for each node of the composition tree. The argument is a tuple of the following form: {:unit, argument} {:times, {argument_1, argument_2}} {:prefix, {prefix_unit, argument}} {:power, {power_unit, argument}} {:per, {argument_1, argument_2}} Where the arguments are the results returned from the fun/1 . Returns The result returned from fun/1","ref":"Cldr.Unit.Format.html#traverse/2","title":"Cldr.Unit.Format.traverse/2","type":"function"},{"doc":"Simple arithmetic functions for the Unit.t type","ref":"Cldr.Unit.Math.html","title":"Cldr.Unit.Math","type":"module"},{"doc":"Adds two compatible %Unit{} types and raises on error Options unit_1 and unit_2 are compatible Units returned by Cldr.Unit.new/2 Returns A %Unit{} of the same type as unit_1 with a value that is the sum of unit_1 and the potentially converted unit_2 or Raises an exception","ref":"Cldr.Unit.Math.html#add!/2","title":"Cldr.Unit.Math.add!/2","type":"function"},{"doc":"Adds two compatible %Unit{} types Options unit_1 and unit_2 are compatible Units returned by Cldr.Unit.new/2 Returns A %Unit{} of the same type as unit_1 with a value that is the sum of unit_1 and the potentially converted unit_2 or {:error, {IncompatibleUnitError, message}} Examples iex&gt; Cldr.Unit.Math . add Cldr.Unit . new! ( :foot , 1 ) , Cldr.Unit . new! ( :foot , 1 ) # Cldr.Unit &lt; :foot , 2 &gt; iex&gt; Cldr.Unit.Math . add Cldr.Unit . new! ( :foot , 1 ) , Cldr.Unit . new! ( :mile , 1 ) # Cldr.Unit &lt; :foot , 5281 &gt; iex&gt; Cldr.Unit.Math . add Cldr.Unit . new! ( :foot , 1 ) , Cldr.Unit . new! ( :gallon , 1 ) { :error , { Cldr.Unit.IncompatibleUnitsError , &quot;Operations can only be performed between units with the same base unit. Received :foot and :gallon&quot; } }","ref":"Cldr.Unit.Math.html#add/2","title":"Cldr.Unit.Math.add/2","type":"function"},{"doc":"","ref":"Cldr.Unit.Math.html#cmp/2","title":"Cldr.Unit.Math.cmp/2","type":"function"},{"doc":"Compare two units, converting to a common unit type if required. If conversion is performed, the results are both rounded to a single decimal place before comparison. Returns :gt , :lt , or :eq . Example iex&gt; x = Cldr.Unit . new! ( :kilometer , 1 ) iex&gt; y = Cldr.Unit . new! ( :meter , 1000 ) iex&gt; Cldr.Unit.Math . compare x , y :eq","ref":"Cldr.Unit.Math.html#compare/2","title":"Cldr.Unit.Math.compare/2","type":"function"},{"doc":"Divides one compatible %Unit{} type by another and raises on error Options unit_1 and unit_2 are compatible Units returned by Cldr.Unit.new/2 Returns A %Unit{} of the same type as unit_1 with a value that is the dividend of unit_1 and the potentially converted unit_2 Raises an exception","ref":"Cldr.Unit.Math.html#div!/2","title":"Cldr.Unit.Math.div!/2","type":"function"},{"doc":"Divides one compatible %Unit{} type by another Options unit_1 and unit_2 are compatible Units returned by Cldr.Unit.new/2 Returns A %Unit{} of the same type as unit_1 with a value that is the dividend of unit_1 and the potentially converted unit_2 {:error, {IncompatibleUnitError, message}} Examples iex&gt; Cldr.Unit . div Cldr.Unit . new! ( :kilogram , 5 ) , Cldr.Unit . new! ( :pound , 1 ) # Cldr.Unit &lt; :kilogram , 8171193714040401 &lt;|&gt; 90071992547409920 &gt; iex&gt; Cldr.Unit . div Cldr.Unit . new! ( :pint , 5 ) , Cldr.Unit . new! ( :liter , 1 ) # Cldr.Unit &lt; :pint , 26938398179283203149098379558387912499591752187904 &lt;|&gt; 63733081193714246983132277926414951878417636536165 &gt; iex&gt; Cldr.Unit . div Cldr.Unit . new! ( :pint , 5 ) , Cldr.Unit . new! ( :pint , 1 ) # Cldr.Unit &lt; :pint , 5.0 &gt;","ref":"Cldr.Unit.Math.html#div/2","title":"Cldr.Unit.Math.div/2","type":"function"},{"doc":"Multiplies two compatible %Unit{} types and raises on error Options unit_1 and unit_2 are compatible Units returned by Cldr.Unit.new/2 Returns A %Unit{} of the same type as unit_1 with a value that is the product of unit_1 and the potentially converted unit_2 Raises an exception","ref":"Cldr.Unit.Math.html#mult!/2","title":"Cldr.Unit.Math.mult!/2","type":"function"},{"doc":"Multiplies two compatible %Unit{} types Options unit_1 and unit_2 are compatible Units returned by Cldr.Unit.new/2 Returns A %Unit{} of the same type as unit_1 with a value that is the product of unit_1 and the potentially converted unit_2 {:error, {IncompatibleUnitError, message}} Examples iex&gt; Cldr.Unit . mult Cldr.Unit . new! ( :kilogram , 5 ) , Cldr.Unit . new! ( :pound , 1 ) # Cldr.Unit &lt; :kilogram , 40855968570202005 &lt;|&gt; 18014398509481984 &gt; iex&gt; Cldr.Unit . mult Cldr.Unit . new! ( :pint , 5 ) , Cldr.Unit . new! ( :liter , 1 ) # Cldr.Unit &lt; :pint , 134691990896416015745491897791939562497958760939520 &lt;|&gt; 12746616238742849396626455585282990375683527307233 &gt; iex&gt; Cldr.Unit . mult Cldr.Unit . new! ( :pint , 5 ) , Cldr.Unit . new! ( :pint , 1 ) # Cldr.Unit &lt; :pint , 5 &gt;","ref":"Cldr.Unit.Math.html#mult/2","title":"Cldr.Unit.Math.mult/2","type":"function"},{"doc":"Rounds the value of a unit. Options unit is any unit returned by Cldr.Unit.new/2 places is the number of decimal places to round to. The default is 0 . mode is the rounding mode to be applied. The default is :half_up . Returns A %Unit{} of the same type as unit with a value that is rounded to the specified number of decimal places Rounding modes Directed roundings: :down - Round towards 0 (truncate), eg 10.9 rounds to 10.0 :up - Round away from 0, eg 10.1 rounds to 11.0. (Non IEEE algorithm) :ceiling - Round toward +∞ - Also known as rounding up or ceiling :floor - Round toward -∞ - Also known as rounding down or floor Round to nearest: :half_even - Round to nearest value, but in a tiebreak, round towards the nearest value with an even (zero) least significant bit, which occurs 50% of the time. This is the default for IEEE binary floating-point and the recommended value for decimal. :half_up - Round to nearest value, but in a tiebreak, round away from 0. This is the default algorithm for Erlang's Kernel.round/2 :half_down - Round to nearest value, but in a tiebreak, round towards 0 (Non IEEE algorithm) Examples iex&gt; Cldr.Unit . round Cldr.Unit . new! ( :yard , 1031.61 ) , 1 # Cldr.Unit &lt; :yard , 1031.6 &gt; iex&gt; Cldr.Unit . round Cldr.Unit . new! ( :yard , 1031.61 ) , 2 # Cldr.Unit &lt; :yard , 1031.61 &gt; iex&gt; Cldr.Unit . round Cldr.Unit . new! ( :yard , 1031.61 ) , 1 , :up # Cldr.Unit &lt; :yard , 1031.7 &gt;","ref":"Cldr.Unit.Math.html#round/3","title":"Cldr.Unit.Math.round/3","type":"function"},{"doc":"Subtracts two compatible %Unit{} types and raises on error Options unit_1 and unit_2 are compatible Units returned by Cldr.Unit.new/2 Returns A %Unit{} of the same type as unit_1 with a value that is the difference between unit_1 and the potentially converted unit_2 Raises an exception","ref":"Cldr.Unit.Math.html#sub!/2","title":"Cldr.Unit.Math.sub!/2","type":"function"},{"doc":"Subtracts two compatible %Unit{} types Options unit_1 and unit_2 are compatible Units returned by Cldr.Unit.new/2 Returns A %Unit{} of the same type as unit_1 with a value that is the difference between unit_1 and the potentially converted unit_2 {:error, {IncompatibleUnitError, message}} Examples iex&gt; Cldr.Unit . sub Cldr.Unit . new! ( :kilogram , 5 ) , Cldr.Unit . new! ( :pound , 1 ) # Cldr.Unit &lt; :kilogram , 81900798833369519 &lt;|&gt; 18014398509481984 &gt; iex&gt; Cldr.Unit . sub Cldr.Unit . new! ( :pint , 5 ) , Cldr.Unit . new! ( :liter , 1 ) # Cldr.Unit &lt; :pint , 36794683014431043834033898368027039378825884348261 &lt;|&gt; 12746616238742849396626455585282990375683527307233 &gt; iex&gt; Cldr.Unit . sub Cldr.Unit . new! ( :pint , 5 ) , Cldr.Unit . new! ( :pint , 1 ) # Cldr.Unit &lt; :pint , 4 &gt;","ref":"Cldr.Unit.Math.html#sub/2","title":"Cldr.Unit.Math.sub/2","type":"function"},{"doc":"Truncates a unit's value","ref":"Cldr.Unit.Math.html#trunc/1","title":"Cldr.Unit.Math.trunc/1","type":"function"},{"doc":"Parse unit strings into composable unit structures. These structures can then be used to produced localized output, or to be converted to another unit of the same unit category.","ref":"Cldr.Unit.Parser.html","title":"Cldr.Unit.Parser","type":"module"},{"doc":"Returns the canonical unit name for a unit or raises on error Arguments unit_string is any string representing a unit such as light_year_per_week . Returns {:ok, canonical_name} or raises an exception Examples iex&gt; Cldr.Unit.Parser . canonical_unit_name! &quot;meter&quot; :meter iex&gt; Cldr.Unit.Parser . canonical_unit_name! &quot;meter meter&quot; :square_meter iex&gt; Cldr.Unit.Parser . canonical_unit_name! &quot;meter per kilogram&quot; &quot;meter_per_kilogram&quot; iex&gt; Cldr.Unit.Parser . canonical_unit_name! &quot;meter kilogram&quot; &quot;kilogram_meter&quot; iex&gt; Cldr.Unit.Parser . canonical_unit_name &quot;curr-usd&quot; { :ok , &quot;curr_usd&quot; } iex&gt; Cldr.Unit.Parser . canonical_unit_name &quot;curr-usd-per-kilogram&quot; { :ok , &quot;curr_usd_per_kilogram&quot; } =&gt; Cldr.Unit.Parser . canonical_unit_name! &quot;meter kilogram per fluxom&quot; ** (CaseClauseError) no case clause matching: {:error, {Cldr.UnknownUnitError, &quot;Unknown unit was detected at &quot;fluxom&quot;&quot;}}","ref":"Cldr.Unit.Parser.html#canonical_unit_name!/1","title":"Cldr.Unit.Parser.canonical_unit_name!/1","type":"function"},{"doc":"Returns the canonical unit name for a unit Arguments unit_string is any string representing a unit such as light_year_per_week . Returns {:ok, canonical_name} or {:error, {exception, reason}} Examples iex&gt; Cldr.Unit.Parser . canonical_unit_name &quot;meter&quot; { :ok , :meter } iex&gt; Cldr.Unit.Parser . canonical_unit_name &quot;meter meter&quot; { :ok , :square_meter } iex&gt; Cldr.Unit.Parser . canonical_unit_name &quot;meter per kilogram&quot; { :ok , &quot;meter_per_kilogram&quot; } iex&gt; Cldr.Unit.Parser . canonical_unit_name &quot;meter kilogram&quot; { :ok , &quot;kilogram_meter&quot; } iex&gt; Cldr.Unit.Parser . canonical_unit_name &quot;meter kilogram per fluxom&quot; { :error , { Cldr.UnknownUnitError , &quot;Unknown unit was detected at \\&quot; fluxom \\&quot; &quot; } }","ref":"Cldr.Unit.Parser.html#canonical_unit_name/1","title":"Cldr.Unit.Parser.canonical_unit_name/1","type":"function"},{"doc":"","ref":"Cldr.Unit.Parser.html#parse_unit!/1","title":"Cldr.Unit.Parser.parse_unit!/1","type":"function"},{"doc":"Parses a unit name expressed as a string and returns the parsed name or an error. Arguments unit_string is a unit name (such as &quot;meter&quot;) as a String.t() Returns {:ok, normalized_unit} or {:error, {exception, reason}} Notes A normalised unit is a 2-tuple with the first element a list of standard units that are before the first &quot;per&quot; in the unit name. The second element is a list of standard units after the first &quot;per&quot; (if any). The structure of the standard unit is {standard_unit, conversion_to_base_unit} . This function is not normally called by consumers of this library. It is called by Cldr.Unit.validate_unit/1 which is the main public API. Example iex&gt; Cldr.Unit.Parser . parse_unit &quot;kilogram per light year&quot; { :ok , { [ { :kilogram , % Cldr.Unit.Conversion { base_unit : [ :kilogram ] , factor : Ratio . new ( 144115188075855875 , 144115188075855872 ) , offset : 0 } } ] , [ { :light_year , % Cldr.Unit.Conversion { base_unit : [ :meter ] , factor : 9460730000000000 , offset : 0 } } ] } }","ref":"Cldr.Unit.Parser.html#parse_unit/1","title":"Cldr.Unit.Parser.parse_unit/1","type":"function"},{"doc":"In many cultures, the common unit of measure for some unit categories varies based upon the usage of the unit. For example, when describing unit length in the US, the common use units vary based upon usage such as: road distance (miles for larger distances, feet for smaller) person height (feet and inches) snowfall (inches) This module provides functions to introspect CLDRs preference data for difference use cases in different locales.","ref":"Cldr.Unit.Preference.html","title":"Cldr.Unit.Preference","type":"module"},{"doc":"Returns a list of the preferred units for a given unit, locale, territory and use case. The units used to represent length, volume and so on depend on a given territory, measurement system and usage. For example, in the US, people height is most commonly referred to in inches , or feet and inches . In most of the rest of the world it is centimeters . Arguments unit is any unit returned by Cldr.Unit.new/2 . backend is any Cldr backend module. That is, any module that includes use Cldr . The default is Cldr.default_backend!/0 options is a keyword list of options or a t:Cldr.Unit.Conversion.Options struct. The default is [] . Options :locale is any valid locale name returned by Cldr.known_locale_names/0 or a Cldr.LanguageTag struct. The default is backend.get_locale/0 :territory is any valid territory code returned by Cldr.known_territories/0 . The default is the territory defined as part of the :locale . The option :territory has a precedence over the territory in a locale. :usage is the way in which the unit is intended to be used. The available usage varyies according to the unit category. See Cldr.Unit.unit_category_usage/0 . Returns unit_list or raises an exception Note This function, unlike Cldr.Unit.preferred_units/3 does not return any available formatting hints. Examples iex&gt; meter = Cldr.Unit . new! ( :meter , 1 ) iex&gt; Cldr.Unit.Preference . preferred_units! meter , MyApp.Cldr , locale : &quot;en-US&quot; , usage : :person_height [ :foot , :inch ] iex&gt; Cldr.Unit.Preference . preferred_units! meter , MyApp.Cldr , locale : &quot;en-US&quot; , usage : :person [ :inch ] iex&gt; Cldr.Unit.Preference . preferred_units! meter , MyApp.Cldr , locale : &quot;en-AU&quot; , usage : :person [ :centimeter ] iex&gt; Cldr.Unit.Preference . preferred_units! meter , MyApp.Cldr , locale : &quot;en-US&quot; , usage : :road [ :foot ] iex&gt; Cldr.Unit.Preference . preferred_units! meter , MyApp.Cldr , locale : &quot;en-AU&quot; , usage : :road [ :meter ]","ref":"Cldr.Unit.Preference.html#preferred_units!/3","title":"Cldr.Unit.Preference.preferred_units!/3","type":"function"},{"doc":"Returns a list of the preferred units for a given unit, locale, territory and use case. The units used to represent length, volume and so on depend on a given territory, measurement system and usage. For example, in the US, people height is most commonly referred to in inches , or informally as feet and inches . In most of the rest of the world it is centimeters . Arguments unit is any unit returned by Cldr.Unit.new/2 . backend is any Cldr backend module. That is, any module that includes use Cldr . The default is Cldr.default_backend!/0 options is a keyword list of options or a t:Cldr.Unit.Conversion.Options struct. The default is [] . Options :usage is the unit usage. for example ;person for a unit of type :length . The available usage for a given unit category can be seen with Cldr.Unit.unit_category_usage/0 . The default is nil . :scope is either :small or nil . In some usage, the units used are different when the unit size is small. It is up to the developer to determine when scope: :small is appropriate. :alt is either :informal or nil . Like :scope , the units in use depend on whether they are being used in a formal or informal context. :locale is any locale returned by Cldr.validate_locale/2 Returns {:ok, unit_list} or {:error, {exception, reason}} Examples iex&gt; meter = Cldr.Unit . new! ( :meter , 1 ) iex&gt; many_meters = Cldr.Unit . new! ( :meter , 10_000 ) iex&gt; Cldr.Unit.Preference . preferred_units meter , MyApp.Cldr , locale : &quot;en-US&quot; , usage : :person { :ok , [ :inch ] , [ ] } iex&gt; Cldr.Unit.Preference . preferred_units meter , MyApp.Cldr , locale : &quot;en-AU&quot; , usage : :person { :ok , [ :centimeter ] , [ ] } iex&gt; Cldr.Unit.Preference . preferred_units meter , MyApp.Cldr , locale : &quot;en-US&quot; , usage : :road { :ok , [ :foot ] , [ round_nearest : 1 ] } iex&gt; Cldr.Unit.Preference . preferred_units many_meters , MyApp.Cldr , locale : &quot;en-US&quot; , usage : :road { :ok , [ :mile ] , [ ] } iex&gt; Cldr.Unit.Preference . preferred_units meter , MyApp.Cldr , locale : &quot;en-AU&quot; , usage : :road { :ok , [ :meter ] , [ round_nearest : 1 ] } iex&gt; Cldr.Unit.Preference . preferred_units many_meters , MyApp.Cldr , locale : &quot;en-AU&quot; , usage : :road { :ok , [ :kilometer ] , [ ] } Notes One common pattern is to convert a given unit into the unit appropriate for a given locale and usage. This can be accomplished with a combination of Cldr.Unit.Preference.preferred_units/3 and Cldr.Unit.decompose/2 . For example: iex&gt; meter = Cldr.Unit . new! ( :meter , 1 ) iex&gt; preferred_units = Cldr.Unit.Preference . preferred_units ( meter , ...&gt; MyApp.Cldr , locale : &quot;en-US&quot; , usage : :person ) iex&gt; with { :ok , preferred_units , _ } &lt;- preferred_units do ...&gt; Cldr.Unit . decompose ( meter , preferred_units ) ...&gt; end [ Cldr.Unit . new! ( :inch , Ratio . new ( 216172782113783808 , 5490788665690109 ) ) ]","ref":"Cldr.Unit.Preference.html#preferred_units/3","title":"Cldr.Unit.Preference.preferred_units/3","type":"function"},{"doc":"","ref":"Cldr.Unit.Preference.html#preferred_units/4","title":"Cldr.Unit.Preference.preferred_units/4","type":"function"},{"doc":"","ref":"Cldr.Unit.Preference.html#unknown_preferences_error/4","title":"Cldr.Unit.Preference.unknown_preferences_error/4","type":"function"},{"doc":"","ref":"Cldr.Unit.Preference.html#unknown_usage_error/2","title":"Cldr.Unit.Preference.unknown_usage_error/2","type":"function"},{"doc":"","ref":"Cldr.Unit.Preference.html#validate_usage/2","title":"Cldr.Unit.Preference.validate_usage/2","type":"function"},{"doc":"","ref":"readme.html","title":"Cldr for Units","type":"extras"},{"doc":"Note that :ex_cldr_units requires Elixir 1.6 or later. Add ex_cldr_units as a dependency to your mix project: defp deps do [ { :ex_cldr_units , &quot;~&gt; 3.0&quot; } ] end then retrieve ex_cldr_units from hex : mix deps . get mix deps . compile","ref":"readme.html#installation","title":"Cldr for Units - Installation","type":"extras"},{"doc":"ex_cldr_units is an add-on library for ex_cldr that provides localisation and formatting for units such as weights, lengths, areas, volumes and so on. It also provides unit conversion and simple arithmetic for compatible units. Configuration From ex_cldr version 2.0, a backend module must be defined into which the public API and the CLDR data is compiled. See the ex_cldr documentation for further information on configuration. In the following examples we assume the presence of a module called MyApp.Cldr defined as: defmodule MyApp.Cldr do use Cldr , locales : [ &quot;en&quot; , &quot;fr&quot; ] , default_locale : &quot;en&quot; , providers : [ Cldr.Number , Cldr.Unit , Cldr.List ] end Supporting the String.Chars protocol The String.Chars protocol underpins Kernel.to_string/1 and is also used in string interpolation such as \#{my_unit} . In order for this to be supported by Cldr.Unit , a default backend module must be configured in config.exs . For example: config :ex_cldr_units , default_backend : MyApp.Cldr","ref":"readme.html#getting-started","title":"Cldr for Units - Getting Started","type":"extras"},{"doc":"The primary api is defined by three functions: MyApp.Cldr.Unit.to_string/2 for formatting units MyApp.Cldr.Unit.new/2 to create a new Unit.t struct that encapsulated a unit and a value that can be used for arithmetic, comparison and conversion MyApp.Cldr.Unit.convert/2 to convert one compatible unit to another MyApp.Cldr.Unit.localize/3 to localize a unit by converting it to units customary for a given territory MyApp.Cldr.Unit.add/2 , MyApp.Cldr.Unit.sub/2 , MyApp.Cldr.Unit.mult/2 , MyApp.Cldr.Unit.div/2 provide basic arithmetic operations on compatible Unit.t structs. Creating a new unit A Cldr.Unit.t() struct is created with the Cldr.Unit.new/2 function. The two parameters are a unit name and a number (expressed as a float , integer , Decimal or Ratio ) in either order. Naming units is quite flexible combining: One or more base unit names. These are the names returned from Cldr.Unit.known_units/0 An optional SI prefix (from yokto to yotta ) An optional power prefix of square or cubic Names can be expressed as strings with any of - , _ or as separators between words. Some examples: iex&gt; Cldr.Unit . new :meter , 1 { :ok , # Cldr.Unit &lt; :meter , 1 &gt; } iex&gt; Cldr.Unit . new &quot;square meter&quot; , 1 { :ok , # Cldr.Unit &lt; :square_meter , 1 &gt; } iex&gt; Cldr.Unit . new &quot;square liter&quot; , 1 { :ok , # Cldr.Unit &lt; &quot;square_liter&quot; , 1 &gt; } iex&gt; Cldr.Unit . new &quot;square yottaliter&quot; , 1 { :ok , # Cldr.Unit &lt; &quot;square_yottaliter&quot; , 1 &gt; } iex&gt; Cldr.Unit . new &quot;cubic light year&quot; , 1 { :ok , # Cldr.Unit &lt; &quot;cubic_light_year&quot; , 1 &gt; } iex&gt; Cldr.Unit . new &quot;squre meter&quot; , 1 { :error , { Cldr.UnknownUnitError , &quot;Unknown unit was detected at \\&quot; squre_meter \\&quot; &quot; } } You will note that the unit make not make logical sense ( cubic light-year ?) but they do make mathematical sense. Units can also be described as the product of one or more base units. For example: iex&gt; Cldr.Unit . new &quot;liter ampere&quot; , 1 { :ok , # Cldr.Unit &lt; &quot;ampere_liter&quot; , 1 &gt; } iex&gt; Cldr.Unit . new &quot;mile lux&quot; , 1 { :ok , # Cldr.Unit &lt; &quot;mile_lux&quot; , 1 &gt; } Again, this may not have a logical meaning but they do have an arithmetic meaning and they can be formatted as strings: iex&gt; Cldr.Unit . new! ( &quot;liter ampere&quot; , 1 ) |&gt; Cldr.Unit . to_string { :ok , &quot;1 ampere⋅litre&quot; } iex&gt; Cldr.Unit . new! ( &quot;mile lux&quot; , 3 ) |&gt; Cldr.Unit . to_string { :ok , &quot;3 miles⋅lux&quot; } Lastly, there are units formed by division where are called &quot;per&quot; units. For example: iex&gt; Cldr.Unit . new &quot;mile per hour&quot; , 1 { :ok , # Cldr.Unit &lt; :mile_per_hour , 1 &gt; } iex&gt; Cldr.Unit . new &quot;liter per second&quot; , 1 { :ok , # Cldr.Unit &lt; &quot;liter_per_second&quot; , 1 &gt; } iex&gt; Cldr.Unit . new &quot;cubic gigalux per inch&quot; , 1 { :ok , # Cldr.Unit &lt; &quot;cubic_gigalux_per_inch&quot; , 1 &gt; } Unit formatting and localization MyApp.Cldr.Unit.to_string/2 provides localized unit formatting. It supports two arguments: number is any number (integer, float or Decimal) or a Unit.t struct returned by Cldr.Unit.new/2 options which are: :unit is any unit returned by Cldr.Unit.known_units/0 . This option is required unless a Unit.t is passed as the first argument. :locale is any configured locale. See Cldr.known_locale_names/0 . The default is locale: Cldr.get_current_locale() :style is one of those returned by Cldr.Unit.available_styles . The current styles are :long , :short and :narrow . The default is style: :long Any other options are passed to Cldr.Number.to_string/2 which is used to format the number iex&gt; MyApp.Cldr.Unit . to_string 123 , unit : :gallon { :ok , &quot;123 gallons&quot; } iex&gt; MyApp.Cldr.Unit . to_string 1234 , unit : :gallon , format : :long { :ok , &quot;1 thousand gallons&quot; } iex&gt; MyApp.Cldr.Unit . to_string 1234 , unit : :gallon , format : :short { :ok , &quot;1K gallons&quot; } iex&gt; MyApp.Cldr.Unit . to_string 1234 , unit : :megahertz { :ok , &quot;1,234 megahertz&quot; } iex&gt; MyApp.Cldr.Unit . to_string 1234 , unit : :foot , locale : &quot;fr&quot; { :ok , &quot;1 234 pieds&quot; } iex&gt; MyApp.Cldr.Unit . to_string Cldr.Unit . new ( :ampere , 42 ) , locale : &quot;fr&quot; { :ok , &quot;42 ampères&quot; } iex&gt; Cldr.Unit . to_string 1234 , MyApp.Cldr , unit : &quot;foot_per_second&quot; , style : :narrow , per : :second { :ok , &quot;1,234′/s&quot; } iex&gt; Cldr.Unit . to_string 1234 , MyApp.Cldr , unit : &quot;foot_per_second&quot; { :ok , &quot;1,234 feet per second&quot; } Unit decomposition Sometimes its a requirement to decompose a unit into one or more subunits. For example, if someone is 6.3 feet height we would normally say &quot;6 feet, 4 inches&quot;. This can be achieved with Cldr.Unit.decompose/2 . Using our example: iex&gt; height = Cldr.Unit . new ( :foot , 6.3 ) # Cldr.Unit &lt; :foot , 6.3 &gt; iex(2)&gt; Cldr.Unit . decompose height , [ :foot , :inch ] [ # Cldr.Unit &lt; :foot , 6.0 &gt; , # Cldr.Unit &lt; :inch , 4.0 &gt; ] A localised string representing this decomposition can also be produced. Cldr.Unit.to_string/3 will process a unit list, using the function Cldr.List.to_string/2 to perform the list combination. Again using the example: iex&gt; c = Cldr.Unit . decompose height , [ :foot , :inch ] [ # Cldr.Unit &lt; :foot , 6.0 &gt; , # Cldr.Unit &lt; :inch , 4.0 &gt; ] iex&gt; Cldr.Unit . to_string c , MyApp.Cldr &quot;6 feet and 4 inches&quot; iex&gt; Cldr.Unit . to_string c , MyApp.Cldr , list_options : [ format : :unit_short ] &quot;6 feet, 4 inches&quot; # And of course full localisation is supported iex&gt; Cldr.Unit . to_string c , MyApp.Cldr , locale : &quot;fr&quot; &quot;6 pieds et 4 pouces&quot; Converting Units t:Unit structs can be converted to other compatible units. For example, feet can be converted to meters since they are both of the length unit type. # Test for unit compatibility iex&gt; Cldr.Unit . compatible? :foot , :meter true iex&gt; Cldr.Unit . compatible? :foot , :liter false # Convert a unit iex&gt; Cldr.Unit . convert Cldr.Unit . new! ( :foot , 3 ) , :meter { :ok , # Cldr.Unit &lt; :meter , 16472365997070327 &lt;|&gt; 18014398509481984 &gt; } Localising units for a given locale or territory Different locales or territories use different measurement systems and sometimes different measurement scales that also vary based upon usage. For example, in the US a person's height is considered in inches up to a certain point and feet and inches after that. For distances when driving, the length is considered in yards for certain distances and miles after that. For most other countries the same quantity would be expressed in centimeters or meters or kilometers . ex_cldr_units makes it easy to take a unit and convert it to the units appropriate for a given locale and usage. Consider this example: iex&gt; height = Cldr.Unit . new! ( 1.81 , :meter ) # Cldr.Unit &lt; :meter , 1.81 &gt; iex&gt; us_height = Cldr.Unit . localize height , usage : :person_height , territory : :US [ # Cldr.Unit &lt; :foot , 5 &gt; , # Cldr.Unit &lt; :inch , 1545635392113553812 &lt;|&gt; 137269716642252725 &gt; ] iex&gt; Cldr.Unit . to_string us_height { :ok , &quot;5 feet and 11.26 inches&quot; } Note that conversion is dependent on context. The context above is :person_height reflecting that we are referring to the height of a person. For units of length category, the other contexts available are :rainfall , :snowfall , :vehicle , :visibility and :road . Using the above example with the context of :rainfall we see iex&gt; length = Cldr.Unit . localize height , usage : :rainfall , territory : :US [ # Cldr.Unit &lt; :inch , 9781818390648717312 &lt;|&gt; 137269716642252725 &gt; ] iex&gt; Cldr.Unit . to_string length { :ok , &quot;71.26 inches&quot; } See Cldr.Unit.preferred_units/3 to see what mappings are available, in particular what context usage is supported for conversion. Unit arithmetic Basic arithmetic is provided by Cldr.Unit.add/2 , Cldr.Unit.sub/2 , Cldr.Unit.mult/2 , Cldr.Unit.div/2 as well as Cldr.Unit.round/3 iex&gt; Cldr.Unit.Math . add Cldr.Unit . new! ( :foot , 1 ) , Cldr.Unit . new! ( :foot , 1 ) # Cldr.Unit &lt; :foot , 2 &gt; iex&gt; Cldr.Unit.Math . add Cldr.Unit . new! ( :foot , 1 ) , Cldr.Unit . new! ( :mile , 1 ) # Cldr.Unit &lt; :foot , 5280.945925937846 &gt; iex&gt; Cldr.Unit.Math . add Cldr.Unit . new! ( :foot , 1 ) , Cldr.Unit . new! ( :gallon , 1 ) { :error , { Cldr.Unit.IncompatibleUnitError , &quot;Operations can only be performed between units of the same type. Received #Cldr.Unit&lt;:foot, 1&gt; and #Cldr.Unit&lt;:gallon, 1&gt;&quot; } } iex&gt; Cldr.Unit . round Cldr.Unit . new ( :yard , 1031.61 ) , 1 # Cldr.Unit &lt; :yard , 1031.6 &gt; iex&gt; Cldr.Unit . round Cldr.Unit . new ( :yard , 1031.61 ) , 1 , :up # Cldr.Unit &lt; :yard , 1031.7 &gt; Available units Available units are returned by Cldr.Unit.known_units/0 . iex&gt; Cldr.Unit . known_units [ :acre , :acre_foot , :ampere , :arc_minute , :arc_second , :astronomical_unit , :bit , :bushel , :byte , :calorie , :carat , :celsius , :centiliter , :centimeter , :century , :cubic_centimeter , :cubic_foot , :cubic_inch , :cubic_kilometer , :cubic_meter , :cubic_mile , :cubic_yard , :cup , :cup_metric , :day , :deciliter , :decimeter , :degree , :fahrenheit , :fathom , :fluid_ounce , :foodcalorie , :foot , :furlong , :g_force , :gallon , :gallon_imperial , :generic , :gigabit , :gigabyte , :gigahertz , :gigawatt , :gram , :hectare , :hectoliter , :hectopascal , :hertz , :horsepower , :hour , :inch , ... ] Unit categories Units are grouped by unit category which defines the convertibility of different types. In general, units of the same category are convertible to each other. The function Cldr.Unit.known_unit_categories/0 returns the unit categories. iex&gt; Cldr.Unit . known_unit_categories [ :acceleration , :angle , :area , :concentr , :consumption , :coordinate , :digital , :duration , :electric , :energy , :frequency , :length , :light , :mass , :power , :pressure , :speed , :temperature , :volume ] See also Cldr.Unit.known_units_by_category/0 and Cldr.Unit.known_units_for_category/1 . Measurement systems Units generally fall into one of three measurement systems in use around the world. In CLDR these are known as :metric , :ussystem and :uksystem . The following functions allow identifying measurement systems for units, territories and locales. The measurement systems are returned with Cldr.Unit.known_measurement_systems/0 . The measurement systems for a given unit are returned by Cldr.Unit.measurement_systems_for_unit/1 . A boolean indicating membership in a given measurement system is returned by Cldr.Unit.measurement_system?/2 . All units belonging to a measurement system are returned by Cldr.Unit.measurement_system_units/1 . The measurement system in use for a given territory is returned by Cldr.Unit.measurement_system_for_territory/1 . The measurement system in use for a given locale is returned by Cldr.Unit.measurement_system_from_locale/1 . Localisation with measurement systems Knowledge of the measurement system in place for a given user helps create a better user experience. For example, a user who prefers units of measure in the US system can be shown different but compatible units from a user who prefers metric units. In this example, the list of units in the volume category are filtered based upon the users preference as expressed by their locale. # For a user preferring US english iex&gt; system = Cldr.Unit . measurement_system_from_locale &quot;en&quot; :ussystem iex&gt; { :ok , units } = Cldr.Unit . known_units_for_category ( :volume ) iex&gt; Enum . filter ( units , &amp; Cldr.Unit . measurement_system? ( &amp;1 , system ) ) [ :dessert_spoon , :cup , :drop , :dram , :cubic_foot , :teaspoon , :tablespoon , :cubic_inch , :bushel , :quart , :pint , :cubic_yard , :cubic_mile , :fluid_ounce , :pinch , :barrel , :jigger , :gallon , :acre_foot ] # For a user preferring australian english iex&gt; system = Cldr.Unit . measurement_system_from_locale &quot;en-AU&quot; :metric iex&gt; Enum . filter ( units , &amp; Cldr.Unit . measurement_system? ( &amp;1 , system ) ) [ :cubic_centimeter , :centiliter , :cubic_meter , :pint_metric , :megaliter , :cubic_kilometer , :hectoliter , :milliliter , :deciliter , :liter , :cup_metric ] # For a user expressing an explicit measurement system iex&gt; system = Cldr.Unit . measurement_system_from_locale &quot;en-AU-u-ms-uksystem&quot; :uksystem iex&gt; Enum . filter ( units , &amp; Cldr.Unit . measurement_system? ( &amp;1 , system ) ) [ :quart_imperial , :cubic_foot , :cubic_inch , :dessert_spoon_imperial , :cubic_yard , :cubic_mile , :fluid_ounce_imperial , :acre_foot , :gallon_imperial ]","ref":"readme.html#public-api","title":"Cldr for Units - Public API","type":"extras"},{"doc":"Additional domain-specific units can be defined to suit application requirements. In the context of ex_cldr there are two parts to configuring additional units. Configure the unit, base unit and conversion in config.exs . This is a requirement since units are compiled into code. Configure the localizations for the additional unit in a CLDR backend module. Once configured, additional units act and behave like any of the predefined units of measure defined by CLDR. Configuring a unit in config.exs Under the application :ex_cldr_units , define a key :additional_units with the required unit definitions. For example: config :ex_cldr_units , :additional_units , vehicle : [ base_unit : :unit , factor : 1 , offset : 0 , sort_before : :all ] , person : [ base_unit : :unit , factor : 1 , offset : 0 , sort_before : :all ] This example defines two additional units: :vehicle and :person . The keys :base_unit , and :factor are required. The key :offset is optional and defaults to 0 . The key :sort_before is optional and defaults to :none . Configuration keys :base_unit is the common denominator that is used to support conversion between like units. It can be any atom value. For example :liter is the base unit for volume units, :meter is the base unit for length units. :factor is used to convert a unit to its base unit in order to support conversion. When converting a unit to another compatible unit, the unit is first multiplied by this units factor then divided by the target units factor. :offset is added to a unit after applying its base factor in order to convert to another unit. :sort_before determines where in this base unit sorts relative to other base units. Typically this is set to :all in which case this base unit sorts before all other base units or :none in which case this base unit sorted after all other base units. The default is :none . If in doubt, leave this key to its default. :systems is list of measurement systems to which this unit belongs. The known measurement systems are :metric , :uksystem and :ussystem . The default is [:metric, :ussystem, :uksystem] . Defining localizations Although defining a unit in config.exs is enough to create, operate on and serialize an additional unit, it cannot be localised without defining localizations in an ex_cldr backend module. For example: defmodule MyApp.Cldr do # Note that this line should come before the `use Cldr` line use Cldr.Unit.Additional use Cldr , locales : [ &quot;en&quot; , &quot;fr&quot; , &quot;de&quot; , &quot;bs&quot; , &quot;af&quot; , &quot;af-NA&quot; , &quot;se-SE&quot; ] , default_locale : &quot;en&quot; , providers : [ Cldr.Number , Cldr.Unit , Cldr.List ] unit_localization ( :person , &quot;en&quot; , :long , one : &quot;{0} person&quot; , other : &quot;{0} people&quot; , display_name : &quot;people&quot; ) unit_localization ( :person , &quot;en&quot; , :short , one : &quot;{0} per&quot; , other : &quot;{0} pers&quot; , display_name : &quot;people&quot; ) unit_localization ( :person , &quot;en&quot; , :narrow , one : &quot;{0} p&quot; , other : &quot;{0} p&quot; , display_name : &quot;p&quot; ) end Note the additions to a typical ex_cldr backend module: use Cldr.Unit.Additional is required to define additional units use of the Cldr.Unit.Additional.unit_localization/4 macro in order to define a localization. The use templates for the localization. Templates are a string with both a placeholder (for units it is always {0} ) and some fixed text that reflects the grammatical requirements of the particular locale. One invocation of Cldr.Unit.Additional.unit_localization/4 should made for each combination of unit, locale and style. Parameters to unit_localization/4 unit is the name of the additional unit as an atom . locale is the locale name for this localization. It should be one of the locale configured in this backend although this cannot currently be confirmed at compile time. style is one of :long , :short , or :narrow . localizations is a keyword like of localization strings. Two keys - :display_name and :other are mandatory. They represent the localizations for a non-count display name and :other is the localization for a unit when no other pluralization is defined. Localisation definition Localization keyword list defines localizations that match the plural rules for a given locale. Plural rules for a given number in a given locale resolve to one of six keys: :zero :one (singular) :two (dual) :few (paucal) :many (also used for fractions if they have a separate class) :other (required — general plural form. Also used if the language only has a single form) Only the :other key is required. For english, providing keys for :one and :other is enough. Other languages have different grammatical requirements. The key :display_name is used by the function Cldr.Unit.display_name/1 which is primarily used to support UI applications. Sorting Units From Elixir 1.10, Enum.sort/2 supports module-based comparisons to provide a simpler API for sorting structs. ex_cldr_units supports Elixir 1.10 as the following example shows: iex&gt; alias Cldr.Unit Cldr.Unit iex&gt; unit_list = [ Unit . new! ( :millimeter , 100 ) , Unit . new! ( :centimeter , 100 ) , Unit . new! ( :meter , 100 ) , Unit . new! ( :kilometer , 100 ) ] [ # Unit &lt; :millimeter , 100 &gt; , # Unit &lt; :centimeter , 100 &gt; , # Unit &lt; :meter , 100 &gt; , # Unit &lt; :kilometer , 100 &gt; ] iex&gt; Enum . sort unit_list , Cldr.Unit [ # Unit &lt; :millimeter , 100 &gt; , # Unit &lt; :centimeter , 100 &gt; , # Unit &lt; :meter , 100 &gt; , # Unit &lt; :kilometer , 100 &gt; ] iex&gt; Enum . sort unit_list , { :desc , Cldr.Unit } [ # Unit &lt; :kilometer , 100 &gt; , # Unit &lt; :meter , 100 &gt; , # Unit &lt; :centimeter , 100 &gt; , # Unit &lt; :millimeter , 100 &gt; ] iex&gt; Enum . sort unit_list , { :asc , Cldr.Unit } [ # Unit &lt; :millimeter , 100 &gt; , # Unit &lt; :centimeter , 100 &gt; , # Unit &lt; :meter , 100 &gt; , # Unit &lt; :kilometer , 100 &gt; ] Note that the items being sorted must be all of the same unit category (length, volume, ...). Where units are of the same category but different units, conversion to a common unit will occur before the comparison. If units of different categories are encountered an exception will be raised as the following example shows: iex&gt; unit_list = [ Unit . new! ( :millimeter , 100 ) , Unit . new! ( :centimeter , 100 ) , Unit . new! ( :meter , 100 ) , Unit . new! ( :liter , 100 ) ] [ # Cldr.Unit &lt; :millimeter , 100 &gt; , # Cldr.Unit &lt; :centimeter , 100 &gt; , # Cldr.Unit &lt; :meter , 100 &gt; , # Cldr.Unit &lt; :liter , 100 &gt; ] iex&gt; Enum . sort unit_list , Cldr.Unit ** (Cldr.Unit.IncompatibleUnitsError) Operations can only be performed between units with the same category and base unit. Received :liter and :meter Serializing to a database with Ecto The companion package ex_cldr_units_sql provides functions for the serialization of Unit data. See the README for further information.","ref":"readme.html#additional-units-custom-units","title":"Cldr for Units - Additional units (custom units)","type":"extras"},{"doc":"","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.14.0 released on October 8th, 2022. For older changelogs please consult the release tag on GitHub Enhancements Add Cldr.Unit.parse_unit_name/2 to parse a string as unit name. Also adds MyApp.Cldr.parse_unit_name/2 as well as the ! versions of these functions. Thanks to @Awlexus for the PR. Closes #31.","ref":"changelog.html#cldr_units-v3-14-0","title":"Changelog - Cldr_Units v3.14.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.13.3 released on August 3rd, 2022. For older changelogs please consult the release tag on GitHub Bug Fixes Fix unit comparison for unit values built from decimal strings. THanks to @seantanly for the report. Closes #29.","ref":"changelog.html#cldr_units-v3-13-3","title":"Changelog - Cldr_Units v3.13.3","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.13.2 released on June 7th, 2022. For older changelogs please consult the release tag on GitHub Bug Fixes Fix MyApp.Cldr.Unit.localize/2 which was previously delegating incorrectly to Cldr.Unit .","ref":"changelog.html#cldr_units-v3-13-2","title":"Changelog - Cldr_Units v3.13.2","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.13.1 released on June 7th, 2022. For older changelogs please consult the release tag on GitHub Bug Fixes Fix Cldr.Unit.Math.* to respect unit :usage of the input parameters Fix Cldr.Math.localize/2 to respect unit :usage of the options parameter if provided","ref":"changelog.html#cldr_units-v3-13-1","title":"Changelog - Cldr_Units v3.13.1","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.13.0 released on April 6th, 2022. For older changelogs please consult the release tag on GitHub Enhancements Update CLDR to release 41 in ex_cldr version 2.28.0 and ex_cldr_numbers 2.26.0 .","ref":"changelog.html#cldr_units-v3-13-0","title":"Changelog - Cldr_Units v3.13.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.12.2 released on February 27th, 2022. For older changelogs please consult the release tag on GitHub Bug Fixes Fixes conversions where the base units don't match (string match) but the units are of the same unit category and therefore are convertible. Thanks to @narrowtux for the report. Fixes #27.","ref":"changelog.html#cldr_units-v3-12-2","title":"Changelog - Cldr_Units v3.12.2","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.12.1 released on February 23rd, 2022. For older changelogs please consult the release tag on GitHub Bug Fixes Remove compilation warning for Phoenix.HTML.Safe that was emitted since the :phoenix_html library is not a dependency. Thanks for @maennchen for the report. Fixes #26.","ref":"changelog.html#cldr_units-v3-12-1","title":"Changelog - Cldr_Units v3.12.1","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.12.0 released on February 21st, 2022. For older changelogs please consult the release tag on GitHub Bug Fixes Fix Cldr.Unit.measurement_system_from_locale/2 to allow the second parameter to be either a backend or a measurement system key. Enhancements Add Cldr.Unit.from_map/1 to create a unit from a map. This can be used to consume the results of serializing a unit to JSON. The input parameter is designed to mirror the output of the custom Jason encoder. Updates to ex_cldr version 2.26.0 and ex_cldr_numbers version 2.25.0 which use atoms for locale names and rbnf locale names. This is consistent with other elements of t:Cldr.LanguageTag where atoms are used when the cardinality of the data is fixed and relatively small and strings where the data is free format.","ref":"changelog.html#cldr_units-v3-12-0","title":"Changelog - Cldr_Units v3.12.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.11.0 released on January 6th, 2022. For older changelogs please consult the release tag on GitHub Bug Fixes Fix canonical base unit calculation when the unit is a per per form like candela per lux . Enhancements Add unit filters for Cldr.Unit.parse/2 . This means that the options :only and :except can comprise both unit categories and unit names as part of the filter.","ref":"changelog.html#cldr_units-v3-11-0","title":"Changelog - Cldr_Units v3.11.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.10.0 released on December 27th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Further refinement to Cldr.Unit.unit_category/1 to return a result in a broader range of cases. Enhancements Adds :only and :except options to Cldr.Unit.parse/2 . These options provide a mechanism to disambiguate the unit when a unit string could refer to more than one unit. For example, &quot;2w&quot; could refer to either &quot;2 weeks&quot; or &quot;2 watts&quot;. If neither option is provided then the result is the same as in prior releases: the unit with the lexically shorter and alphabetically earlier unit is returned.","ref":"changelog.html#cldr_units-v3-10-0","title":"Changelog - Cldr_Units v3.10.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.9.2 released on December 26th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fix Cldr.Unit.unit_category/1 . Thanks to @DaTrader for the report. Closes #24.","ref":"changelog.html#cldr_units-v3-9-2","title":"Changelog - Cldr_Units v3.9.2","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.9.1 released on November 15th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Support parsing units with multiple &quot;per&quot; clauses like &quot;gallon per feet per second&quot;. Fix canonical unit name for currency units. This also fixes unit math with currency units. Add display_name/2 to backend modules.","ref":"changelog.html#cldr_units-v3-9-1","title":"Changelog - Cldr_Units v3.9.1","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.9.0 released on November 14th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Use import Config not deprecated use Mix.Config in config files. Only significant for developers of ex_cldr_units . Make decimal a required dependency, not optional, since various pattern matches expect its presence. Enhancements Add support for currency-based units. This allows for calculations and formatting of units such as &quot;$2 per gallon&quot;. For this example, the unit would be created with Cldr.Unit.new(2, &quot;curr-usd-per-gallon&quot;) . The inverse is also possible, for example: iex&gt; MyApp.Cldr.Unit . to_string ( Cldr.Unit . new! ( 2 , &quot;curr-usd-per-gallon&quot; ) ) { :ok , &quot;$2.00 per gallon&quot; } iex&gt; MyApp.Cldr.Unit . to_string ( Cldr.Unit . new! ( 2 , &quot;gallon-per-curr-usd&quot; ) ) { :ok , &quot;2 gallons per US dollar&quot; } Add support for binary factor prefixed units. These units are factors of 1024 and include &quot;kibi&quot;, &quot;mebi&quot;, &quot;gibi&quot;, &quot;tebi&quot;, &quot;pebi&quot;, &quot;exbi&quot;, &quot;zebi&quot; and &quot;yobi&quot;. For example: iex&gt; MyApp.Cldr.Unit . to_string Cldr.Unit . new! ( 3 , :gibibyte ) { :ok , &quot;3 gibibytes&quot; } Add support for integer prefixes for units. This is useful for units like &quot;liters per 100 kilometers&quot; or &quot;25 calories per 100 grams&quot;. For example: iex&gt; MyApp.Cldr.Unit . to_string Cldr.Unit . new! ( 25 , &quot;calorie_per_100-gram&quot; ) { :ok , &quot;25 calories per 100 grams&quot; }","ref":"changelog.html#cldr_units-v3-9-0","title":"Changelog - Cldr_Units v3.9.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.8.0 released on October 27th, 2021. For older changelogs please consult the release tag on GitHub Enhancements Updates to use CLDR 40 data. The release notes say: In CLDR v40, the focus is on Grammatical features (gender and case) for units of measurement in additional locales. In many languages, forming grammatical phrases requires dealing with grammatical gender and case. Without that, it can sound as bad as &quot;on top of 3 hours&quot; instead of &quot;in 3 hours&quot;: Phase 1 (CLDR v39) of grammatical features included just 12 locales (da, de, es, fr, hi, it, nl, no, pl, pt, ru, sv). Phase 2 (CLDR v40, this release) has expanded the number of locales by 29 (am, ar, bn, ca, cs, el, fi, gu, he, hr, hu, hy, is, kn, lt, lv, ml, mr, nb, pa, ro, si, sk, sl, sr, ta, te, uk, ur), but for a more restricted number of units. Deprecations Don't call deprecated Cldr.Config.get_locale/2 , use Cldr.Locale.Loader.get_config/2 instead. Don't call deprecated Cldr.Config.known_locale_names/1 , call Cldr.Locale.Loader.known_locale_names/1 instead.","ref":"changelog.html#cldr_units-v3-8-0","title":"Changelog - Cldr_Units v3.8.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.8.0-rc.2 released on October 25th, 2021. For older changelogs please consult the release tag on GitHub Deprecations Don't call deprecated Cldr.Config.known_locale_names/1 , call Cldr.Locale.Loader.known_locale_names/1 instead.","ref":"changelog.html#cldr_units-v3-8-0-rc-2","title":"Changelog - Cldr_Units v3.8.0-rc.2","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.8.0-rc.1 released on October 24th, 2021. For older changelogs please consult the release tag on GitHub Deprecations Don't call deprecated Cldr.Config.get_locale/2 , use Cldr.Locale.Loader.get_config/2 instead.","ref":"changelog.html#cldr_units-v3-8-0-rc-1","title":"Changelog - Cldr_Units v3.8.0-rc.1","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.8.0-rc.0 released on October 3rd, 2021. For older changelogs please consult the release tag on GitHub Enhancements Updates to use CLDR 40 data. The release notes say: In CLDR v40, the focus is on Grammatical features (gender and case) for units of measurement in additional locales. In many languages, forming grammatical phrases requires dealing with grammatical gender and case. Without that, it can sound as bad as &quot;on top of 3 hours&quot; instead of &quot;in 3 hours&quot;: Phase 1 (CLDR v39) of grammatical features included just 12 locales (da, de, es, fr, hi, it, nl, no, pl, pt, ru, sv). Phase 2 (CLDR v40, this release) has expanded the number of locales by 29 (am, ar, bn, ca, cs, el, fi, gu, he, hr, hu, hy, is, kn, lt, lv, ml, mr, nb, pa, ro, si, sk, sl, sr, ta, te, uk, ur), but for a more restricted number of units.","ref":"changelog.html#cldr_units-v3-8-0-rc-0","title":"Changelog - Cldr_Units v3.8.0-rc.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.7.1 released on August 20th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fix doc errors. Thanks to @maennchen for the report. Doc errors in other ex_cldr packages are also updated.","ref":"changelog.html#cldr_units-v3-7-1","title":"Changelog - Cldr_Units v3.7.1","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.7.0 released on July 1st, 2021. For older changelogs please consult the release tag on GitHub Enhancements Add support for the Cldr.DisplayName protocol for t:Cldr.Unit structs. Updated to ex_cldr version 2.23.0 which changes the names of some of the fields in the &quot;-u-&quot; extension to match the CLDR canonical name. In particular the field name measurement_system changes to ms . Also the value of ms for the UK System will be :imperial not :uksystem .","ref":"changelog.html#cldr_units-v3-7-0","title":"Changelog - Cldr_Units v3.7.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.6.0 released on June 12th, 2021. For older changelogs please consult the release tag on GitHub Enhancements Add Cldr.Unit.parse/2 to parse unit strings of the form 1kg into a t:Cldr.Unit struct.","ref":"changelog.html#cldr_units-v3-6-0","title":"Changelog - Cldr_Units v3.6.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.5.3 released on May 20th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fixes formatting units when invoking MyApp.Cldr.Unit.to_string/2 (ie on the backend module) and no default backend is configured. Thanks again to @maennchen. Closes #22. Require at least ex_cldr version 2.22.1","ref":"changelog.html#cldr_units-v3-5-3","title":"Changelog - Cldr_Units v3.5.3","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.5.2 released on April 12th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fix getting a unit pattern when the unit value is zero, one or two and there is no pattern for the default unit plural category. Thanks to @syfgkjasdkn for the report. Closes #21.","ref":"changelog.html#cldr_units-v3-5-2","title":"Changelog - Cldr_Units v3.5.2","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.5.1 released on April 11th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Use :other plural category to format units which have a value of 0, 1 or 2 when the natural unit pattern has no substitutions. This corrects the situation in locales such as he and ar where the unit pattern for plural category :one has no substitutions. Previously this would means the formatted string for a unit with a value of 1 and -1 would both output the same string. Thanks to @jarrodmoldrich for the report and to @voltone for his family's help with hebrew grammar.","ref":"changelog.html#cldr_units-v3-5-1","title":"Changelog - Cldr_Units v3.5.1","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.5.0 released on April 8th, 2021. For older changelogs please consult the release tag on GitHub Overview In this release the Cldr.Unit.to_string/{1, 2, 3} function has been rewritten and the concrete implementation is now in Cldr.Unit.Format . The primary reasons for rewriting are: Improves performance by 20% over the old implementation. Supports grammatical case and grammatical gender. These allow for better sentence formation in a localised fashion. Only are few locales have the required data for now (for example, fr and de ) however more locales will have data in upcoming CLDR releases. Note that full testing of grammatical case and grammatical gender variations is not yet complete. Soft Deprecation The function Cldr.Unit.to_iolist/{1, 2, 3} is soft deprecated. It is still available and no deprecation warning is emitted. It will however be removed from the public API in a future release. This function is primarily used to support implementation of Cldr.Unit.to_string/3 As of this release, argument checking in Cldr.Unit.to_iolist/3 is less rigorous in order to avoid the relatively expensive argument normalization process happening twice (once in Cldr.Unit.to_string/3 and then again in Cldr.Unit.to_iolist/3 ). Bug Fixes The new string formatter correctly assembles units with an SI prefix (ie millimeter ) in languages such as German where the noun is capitalized. Fixes calculating the base unit when the unit is a complex compound unit. Remove double parsing when calling Cldr.Unit.new/2 and the unit is not in Cldr.Unit.known_units/0 Ensure Cldr.Unit.unit_category/1 returns an error tuple if the category is unknown Enhancements Updated to require ex_cldr version 2.20 which includes CLDR 39 data. Add Cldr.Unit.validate_grammatical_gender/2 Add Cldr.Unit.known_grammatical_cases/0 Add Cldr.Unit.known_grammatical_genders/0 Add Cldr.Unit.known_measurement_system_names/0 Add Cldr.Unit.invert/1 to invert a &quot;per&quot; unit. This allows for increased compatibility for conversions. For example, &quot;liters per 100 kilometers&quot; is a measure of consumption, as is &quot;miles per gallon&quot;. However these two units are not convertible without inverting one of them first since one is &quot;volume per length&quot; and the other is &quot;length per volume&quot;. Add Cldr.Unit.conversion_for/2 to return a conversion list used when converting one unit to another. Add Cldr.Unit.grammatical_gender/2 to return the grammatical gender for a given unit and locale Add Cldr.Unit.conversion_for/2 to return a conversion list used when converting one unit to another. Add support for grammatical cases for Cldr.Unit.to_string/2 and Cldr.Unit.to_iolist/2 . Not all locales support more than the nominative case. The nominative case is the default. Any configured &quot;Additional Units&quot; in a backend module will need to be modified to put the localisations a map with the key :nominative . See the readme for more information on migrating additional units. On example is: defmodule MyApp.Cldr do use Cldr.Unit.Additional use Cldr , locales : [ &quot;en&quot; , &quot;fr&quot; , &quot;de&quot; , &quot;bs&quot; , &quot;af&quot; , &quot;af-NA&quot; , &quot;se-SE&quot; ] , default_locale : &quot;en&quot; , providers : [ Cldr.Number , Cldr.Unit , Cldr.List ] unit_localization ( :person , &quot;en&quot; , :long , nominative : %{ one : &quot;{0} person&quot; , other : &quot;{0} people&quot; } , display_name : &quot;people&quot; ) end Support conversions where one of the base units is the inverted conversion of the other. This allows conversion between, for example, mile per gallon and liter per 100 kilometer . These are both compound units of length and volume but are inverse representations from each other.","ref":"changelog.html#cldr_units-v3-5-0","title":"Changelog - Cldr_Units v3.5.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.5.0-rc.1 released on March 21st, 2021. For older changelogs please consult the release tag on GitHub Overview In this release the Cldr.Unit.to_string/{1, 2, 3} function has been rewritten and the concrete implementation is now in Cldr.Unit.Format . The primary reasons for rewriting are: Improves performance by 20% over the old implementation. Supports grammatical case and grammatical gender. These allow for better sentence formation in a localised fashion. Only are few locales have the required data for now (for example, fr and de ) however more locales will have data in upcoming CLDR releases. Note that full testing of grammatical case and grammatical gender variations is not yet complete. Soft Deprecation The function Cldr.Unit.to_iolist/{1, 2, 3} is soft deprecated. It is still available and no deprecation warning is emitted. It will however be removed from the public API in a future release. This function is primarily used to support implementation of Cldr.Unit.to_string/3 As of this release, argument checking in Cldr.Unit.to_iolist/3 is less rigorous in order to avoid the relatively expensive argument normalization process happening twice (once in Cldr.Unit.to_string/3 and then again in Cldr.Unit.to_iolist/3 ). Bug Fixes The new string formatter correctly assembles units with an SI prefix (ie millimeter ) in languages such as German where the noun is capitalized.","ref":"changelog.html#cldr_units-v3-5-0-rc-1","title":"Changelog - Cldr_Units v3.5.0-rc.1","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.5.0-rc.0 released on March 19th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fixes calculating the base unit when the unit is a complex compound unit. Remove double parsing when calling Cldr.Unit.new/2 and the unit is not in Cldr.Unit.known_units/0 Ensure Cldr.Unit.unit_category/1 returns an error tuple if the category is unknown Enhancements Updated to require ex_cldr version 2.20 which includes CLDR 39 data. Add Cldr.Unit.known_grammatical_cases/0 Add Cldr.Unit.known_grammatical_genders/0 Add Cldr.Unit.known_measurement_system_names/0 Add Cldr.Unit.invert/1 to invert a &quot;per&quot; unit. This allows for increased compatibility for conversions. For example, &quot;liters per 100 kilometers&quot; is a measure of consumption, as is &quot;miles per gallon&quot;. However these two units are not convertible without inverting one of them first since one is &quot;volume per length&quot; and the other is &quot;length per volume&quot;. Add Cldr.Unit.conversion_for/2 to return a conversion list used when converting one unit to another. Add Cldr.Unit.grammatical_gender/2 to return the grammatical gender for a given unit and locale Add Cldr.Unit.conversion_for/2 to return a conversion list used when converting one unit to another. Add support for grammatical cases for Cldr.Unit.to_string/2 and Cldr.Unit.to_iolist/2 . Not all locales support more than the nominative case. The nominative case is the default. Any configured &quot;Additional Units&quot; in a backend module will need to be modified to put the localisations a map with the key :nominative . See the readme for more information on migrating additional units. On example is: defmodule MyApp.Cldr do use Cldr.Unit.Additional use Cldr , locales : [ &quot;en&quot; , &quot;fr&quot; , &quot;de&quot; , &quot;bs&quot; , &quot;af&quot; , &quot;af-NA&quot; , &quot;se-SE&quot; ] , default_locale : &quot;en&quot; , providers : [ Cldr.Number , Cldr.Unit , Cldr.List ] unit_localization ( :person , &quot;en&quot; , :long , nominative : %{ one : &quot;{0} person&quot; , other : &quot;{0} people&quot; } , display_name : &quot;people&quot; ) end Support conversions where one of the base units is the inverted conversion of the other. This allows conversion between, for example, mile per gallon and liter per 100 kilometer . These are both compound units of length and volume but are inverse representations from each other.","ref":"changelog.html#cldr_units-v3-5-0-rc-0","title":"Changelog - Cldr_Units v3.5.0-rc.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.4.0 released on February 9th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fix readme example for MyApp.Cldr.Unit.convert/2 . Thanks to @DamienFF. Closes #16. Add missing &lt;backend&gt;.convert!/2 Enhancements Supports the definition of custom units in config.exs . Add Cldr.Unit.display_name/2 Add Cldr.Unit.known_units_by_category/0 Add Cldr.Unit.known_units_for_category/1 Add Cldr.Unit.measurement_system_units/0 Add Cldr.Unit.measurement_system_from_locale/{2, 3} Add Cldr.Unit.measurement_system_for_territory/1 Add Cldr.Unit.measurement_systems_for_unit/1 Improve Cldr.Unit.IncompatibleUnit exception error message Deprecate Cldr.Unit.measurement_systems/0 in favour of Cldr.Unit.measurement_systems_by_territory/0 Requires ex_cldr version ~&gt; 2.19 which includes the localised display name of units","ref":"changelog.html#cldr_units-v3-4-0","title":"Changelog - Cldr_Units v3.4.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.3.1 released on November 3rd, 2020. For older changelogs please consult the release tag on GitHub Bug Fixes Fix Cldr.Unit.localize/2 when no options are provided","ref":"changelog.html#cldr_units-v3-3-1","title":"Changelog - Cldr_Units v3.3.1","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.3.0 released on November 1st, 2020. For older changelogs please consult the release tag on GitHub Enhancements Update to CLDR38","ref":"changelog.html#cldr_units-v3-3-0","title":"Changelog - Cldr_Units v3.3.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.2.1 released on September 26th, 2020. For older changelogs please consult the release tag on GitHub Bug Fixes Use Cldr.default_backend!/0 when available (as in later ex_cldr releases) since Cldr.default_backend/0 is deprecated.","ref":"changelog.html#cldr_units-v3-2-1","title":"Changelog - Cldr_Units v3.2.1","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.2.0 released on September 5th, 2020. For older changelogs please consult the release tag on GitHub Enhancements Support string form of unit usage when passed as option :usage to Cldr.Unit.new/3 . This is required to support improved serialization in ex_cldr_units_sql Bug Fixes Correct the documentation to reflect the option :usage to Cldr.Unit.new/3 rather than the incorrect :use . Fix spec for Cldr.Units.compatible?/2 . Thanks to @lostkobrakai.","ref":"changelog.html#cldr_units-v3-2-0","title":"Changelog - Cldr_Units v3.2.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.1.2 released on August 29th, 2020. For older changelogs please consult the release tag on GitHub Bug Fixes Fixes dialyzer warning on Cldr.Unit.to_string/3 and Cldr.Unit.to_string!/3 . Thanks to @maennchen for the report. Closes #15. Support Decimal numbers in Cldr.Unit.to_string/3 and Cldr.Unit.to_string!/3 .","ref":"changelog.html#cldr_units-v3-1-2","title":"Changelog - Cldr_Units v3.1.2","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.1.1 released on June 29th, 2020. For older changelogs please consult the release tag on GitHub Bug Fixes Ensure that :locale is passed through to Cldr.Number.to_string/3 . Thanks for the PR to @Zurga. Closes #14.","ref":"changelog.html#cldr_units-v3-1-1","title":"Changelog - Cldr_Units v3.1.1","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.1.0 released on May 18th, 2020. For older changelogs please consult the release tag on GitHub Enhancements Add Cldr.Unit.to_iolist/3 and Cldr.Unit.to_iolist!/3 to return the formatted unit as an iolist rather than a string. This allows for formatting the number and the unit name differently. It also allows some efficiency in inserting formatted content into a Phoenix workflow since it handles iolists efficiently. Bug Fixes Fix resolving translatable unit names from strings Fix converting translatable units that have a &quot;per&quot; conversion","ref":"changelog.html#cldr_units-v3-1-0","title":"Changelog - Cldr_Units v3.1.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.0.1 released on May 15th, 2020. For older changelogs please consult the release tag on GitHub Bug Fixes Corrects unit creation when the unit itself is directly translatable (like :kilowatt_hour ) but there is no explicit conversion, just an implicit calculated conversion. Thanks to @syfgkjasdkn.","ref":"changelog.html#cldr_units-v3-0-1","title":"Changelog - Cldr_Units v3.0.1","type":"extras"},{"doc":"This is the changelog for Cldr_units v3.0.0 released on May 4th, 2020. For older changelogs please consult the release tag on GitHub Summary New unit creation including rational numbers Base unit calculation New unit preferences New conversion engine Breaking changes Cldr.Unit.new/2 is now Cldr.Unit/{2, 3} and it returns a standard {:ok, unit} tuple on success. Use Cldr.Unit.new!/{2,3} if you want to retain the previous behaviour. Removed Cldr.Unit.unit_tree/0 Removed Cldr.Unit.units/1 Removed Cldr.Unit.compatible_units/2 Removed Cldr.Unit.best_match/1 Removed Cldr.Unit.jaro_match/1 Removed Cldr.Unit.unit_category_map/0 (replaced with Cldr.Unit.base_unit_category_map/0 ) Deprecations Deprecate Cldr.Unit.unit_categories/0 in favour of Cldr.Unit.known_unit_categories/0 to be consistent across CLDR. Enhancements Incorporate CLDR's unit conversion data into the new conversion engine Unit values may now be rational numbers. Conversion data and the results of conversions are executed and retained as rationals. New units can be created with integer, float, Decimal or rational numbers. Conversion to floats is done only when the unit is output via Cldr.Unit.to_string/3 or explicitly through the new function Cldr.Unit.ratio_to_float/1 Add an option :usage to Cldr.Unit.new/{2,3} . This defines an expected usage for a given unit that will be applied during localization. The default is :default . See Cldr.Unit.unit_category_map/0 for what usage is defined for a unit category. Add Cldr.Unit.known_measurement_sytems/0 to return the known measurement systems Add Cldr.Unit.Conversion.preferred_units/3 that returns a list of preferred units for a given unit. This makes it straight forward to take a unit and convert it to the units preferred by the user for a given unit type, locale and use case. Add Cldr.Unit.base_category_map/0 that maps base units to their unit categories. For example, map mile_per_hour to :speed or kilogram_square_meter_per_cubic_second_ampere to :voltage . Base units are derived from a unit name and are not normally the concern of the consumer of ex_cldr_units .","ref":"changelog.html#cldr_units-v3-0-0","title":"Changelog - Cldr_Units v3.0.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v2.8.1 released on April 25th, 2020. For older changelogs please consult the release tag on GitHub Enhancements Updates data management to be compatible with data from both both CLDR 36 (ex_cldr 2.13) and CLDR 37 (ex_cldr 2.14)","ref":"changelog.html#cldr_units-v2-8-1","title":"Changelog - Cldr_Units v2.8.1","type":"extras"},{"doc":"This is the changelog for Cldr_units v2.8.0 released on January 27th, 2020. For older changelogs please consult the release tag on GitHub Enhancements Support the new Enum.sort/2 in Elixir 1.10. The function Cldr.Math.cmp/2 is deprecated in favour of Cldr.Math.compare/2 that has the same function signature and returns the same result that is compatible with Elixir 1.10. Adds Cldr.Unit.compare/2 that is required for Enum.sort/2 to work as expected with units. As an example: iex&gt; alias Cldr.Unit Cldr.Unit iex&gt; unit_list = [ Unit . new ( :millimeter , 100 ) , Unit . new ( :centimeter , 100 ) , Unit . new ( :meter , 100 ) , Unit . new ( :kilometer , 100 ) ] [ # Unit &lt; :millimeter , 100 &gt; , # Unit &lt; :centimeter , 100 &gt; , # Unit &lt; :meter , 100 &gt; , # Unit &lt; :kilometer , 100 &gt; ] iex&gt; Enum . sort unit_list , Cldr.Unit [ # Unit &lt; :millimeter , 100 &gt; , # Unit &lt; :centimeter , 100 &gt; , # Unit &lt; :meter , 100 &gt; , # Unit &lt; :kilometer , 100 &gt; ] iex&gt; Enum . sort unit_list , { :desc , Cldr.Unit } [ # Unit &lt; :kilometer , 100 &gt; , # Unit &lt; :meter , 100 &gt; , # Unit &lt; :centimeter , 100 &gt; , # Unit &lt; :millimeter , 100 &gt; ] iex&gt; Enum . sort unit_list , { :asc , Cldr.Unit } [ # Unit &lt; :millimeter , 100 &gt; , # Unit &lt; :centimeter , 100 &gt; , # Unit &lt; :meter , 100 &gt; , # Unit &lt; :kilometer , 100 &gt; ]","ref":"changelog.html#cldr_units-v2-8-0","title":"Changelog - Cldr_Units v2.8.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v2.7.0 released on October 10th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Update ex_cldr to version 2.11.0 which encapsulates CLDR version 36.0.0 data. Update minimum Elixir version to 1.6 Adds conversion for newton meter , dalton , solar luminosity , pound foot , bar , newton , electron volt , barrel , dunam , decade , mole , pound force , megapascal , pascal , kilopascal , solar radius , therm US , British thermal unit , earth mass .","ref":"changelog.html#cldr_units-v2-7-0","title":"Changelog - Cldr_Units v2.7.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v2.6.1 released on August 31st, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fix Cldr.Unit.to_string/3 to ensure that {:ok, string} is returned when formatting a list of units","ref":"changelog.html#cldr_units-v2-6-1","title":"Changelog - Cldr_Units v2.6.1","type":"extras"},{"doc":"This is the changelog for Cldr_units v2.6.0 released on August 25th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Add Cldr.Unit.localize/3 to support converting a given unit into units that are familiar to a given territory. For example, given a unit of #Unit&lt;2, :meter&gt; is would normally be expected to show this as [#Unit&lt;:foot, 5&gt;, #Unit&lt;:inch, 11&gt;] . The data to support these conversions is returned by Cldr.Unit.unit_preferences/0 . An example: iex&gt; height = Cldr.Unit . new ( 1.8 , :meter ) iex&gt; Cldr.Unit . localize height , :person , territory : :US , style : :informal [ # Unit &lt; :foot , 5 &gt; , # Unit &lt; :inch , 11 &gt; ] Note that conversion is dependent on context. The context above is :person reflecting that we are referring to the height of a person. For units of length category, the other contexts available are :rainfall , :snowfall , :vehicle , :visibility and :road . Using the above example with the context of :rainfall we see iex&gt; Cldr.Unit . localize height , :rainfall , territory : :US [ # Unit &lt; :inch , 71 &gt; ] Adds a :per option to Cldr.Unit.to_string/3 . This option leverages the per formatting style to allow compound units to be printed. For example, assume want to emit a string which represents &quot;kilograms per second&quot;. There is no such unit defined in CLDR (or perhaps anywhere!). But if we define the unit unit = Cldr.Unit.new(:kilogram, 20) we can then execute Cldr.Unit.to_string(unit, per: :second) . Each locale defines a specific way to format such a compound unit. Usually it will return something like 20 kilograms/second Adds Cldr.Unit.unit_preferences/0 to map units into a territory preference alternative unit Adds Cldr.Unit.measurement_systems/0 that identifies the unit system in use for a territory Adds Cldr.Unit.measurement_system_for/1 that returns the measurement system in use for a given territory. The result will be one of :metric , :US or :UK . Deprecation Add Cldr.Unit.unit_category/1 and deprecate Cldr.Unit.unit_type/1 in order to be consistent with the nomenclature of CLDR","ref":"changelog.html#cldr_units-v2-6-0","title":"Changelog - Cldr_Units v2.6.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v2.5.3 released on August 23rd, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fix @spec for Cldr.Unit.to_string/3 and Cldr.Unit.to_string!/3","ref":"changelog.html#cldr_units-v2-5-3","title":"Changelog - Cldr_Units v2.5.3","type":"extras"},{"doc":"This is the changelog for Cldr_units v2.5.2 released on August 21st, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Replace Cldr.get_current_locale/0 with Cldr.get_locale/0 in docs Fix dialyzer warnings","ref":"changelog.html#cldr_units-v2-5-2","title":"Changelog - Cldr_Units v2.5.2","type":"extras"},{"doc":"This is the changelog for Cldr_units v2.5.1 released on June 18th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Standardize the development cldr backend as MyApp.Cldr which makes for more understandable and readable examples and doc tests Cldr.Unit.to_string/3 now allows for the backend parameter to default to Cldr.default_backend/0","ref":"changelog.html#cldr_units-v2-5-1","title":"Changelog - Cldr_Units v2.5.1","type":"extras"},{"doc":"This is the changelog for Cldr_units v2.5.0 released on March 28th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Updates to CLDR version 35.0.0 released on March 27th 2019.","ref":"changelog.html#cldr_units-v2-5-0","title":"Changelog - Cldr_Units v2.5.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v2.4.0 released on March 23rd, 2019. For older changelogs please consult the release tag on GitHub Enhancements Supports Cldr.default_backend() as a default for backend parameters in Cldr.Unit","ref":"changelog.html#cldr_units-v2-4-0","title":"Changelog - Cldr_Units v2.4.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v2.3.2 released on March 23rd, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Include priv directory in the hex package (that's where the conversion json exists)","ref":"changelog.html#cldr_units-v2-3-3","title":"Changelog - Cldr_Units v2.3.3","type":"extras"},{"doc":"This is the changelog for Cldr_units v2.3.2 released on March 20th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fix dialyzer warnings","ref":"changelog.html#cldr_units-v2-3-2","title":"Changelog - Cldr_Units v2.3.2","type":"extras"},{"doc":"This is the changelog for Cldr_units v2.3.1 released on March 15th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Makes generation of documentation for backend modules optional. This is implemented by the :generate_docs option to the backend configuration. The default is true . For example: defmodule MyApp.Cldr do use Cldr , default_locale : &quot;en-001&quot; , locales : [ &quot;en&quot; , &quot;ja&quot; ] , gettext : MyApp.Gettext , generate_docs : false end","ref":"changelog.html#cldr_units-v2-3-1","title":"Changelog - Cldr_Units v2.3.1","type":"extras"},{"doc":"This is the changelog for Cldr_units v2.3.0 released on March 4th, 2019. For older changelogs please consult the release tag on GitHub Enhancements The conversion tables are now stored as json and updates may be downloaded at any time with the mix task mix cldr.unit.download . This means that updates to the conversion table may be made without requiring a new release of Cldr.Unit .","ref":"changelog.html#cldr_units-v2-3-0","title":"Changelog - Cldr_Units v2.3.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v2.2.0 released on February 24th, 2019. For older changelogs please consult the release tag on GitHub Enhancements This release is primarily about improving the conversion of units without introducing precision errors that accumulate for floats. The strategy is to define the conversion value between individual unit pairs. Currently the implementation uses a static map. In order to give users a better experience a future release will allow for both specifying mappings as a parameter to Cldr.Unit.convert/2 and as compile time configuration options including the option to download conversion tables from the internet. Direct conversions are now supported. For some calculations, the process of diving and multiplying by conversion factors produces an unexpected result. Some direct conversions are now defined which produce a more expected result. In most cases, return integer values from conversion and decomposition when the originating unit value is also an integer","ref":"changelog.html#cldr_units-v2-2-0","title":"Changelog - Cldr_Units v2.2.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v2.1.0 released on December 8th, 2018. For older changelogs please consult the release tag on GitHub Enhancements Add Cldr.Unit.Conversion.convert!/2 Add Cldr.Unit.Math.cmp/2 Add Cldr.Unit.decompose/2 Add Cldr.Unit.zero/1 Add Cldr.Unit.zero?/1 The appropriate backend equivalents are also added.","ref":"changelog.html#cldr_units-v2-1-0","title":"Changelog - Cldr_Units v2.1.0","type":"extras"},{"doc":"This is the changelog for Cldr_units v2.0.0 released on November 24th, 2018. For older changelogs please consult the release tag on GitHub Breaking changes Cldr.Unit now requires a Cldr backend module to be configured In order for the String.Chars protocol to be supported (which is used in string interpolation and by Kernel.to_string/1 ) a default backend must be configured. For example in config.exs : config :ex_cldr_units , default_backend : MyApp.Cldr Enhancements Move to a backend module structure with ex_cldr version 2.0","ref":"changelog.html#cldr_units-v2-0-0","title":"Changelog - Cldr_Units v2.0.0","type":"extras"},{"doc":"","ref":"license.html","title":"LICENSE","type":"extras"},{"doc":"Copyright 2017 Kip Cole Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http :// www . apache . org / licenses / LICENSE - 2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.","ref":"license.html#license","title":"LICENSE - License","type":"extras"}]